USE ChangeDataCapture
GO
IF EXISTS (SELECT * FROM sys.tables WHERE [name] = 'Product')
DROP TABLE [dbo].[Product]
GO
CREATE TABLE [dbo].[Product](
	[ProductID] [int] NOT NULL,
	[Name] [nvarchar](50) NULL,
	[ProductNumber] [nvarchar](25) NULL,
	[MakeFlag] [bit] NULL,
	[FinishedGoodsFlag] [bit] NULL,
	[Color] [nvarchar](15) NULL,
	[SafetyStockLevel] [smallint] NULL,
	[ReorderPoint] [smallint] NULL,
	[StandardCost] [money] NULL,
	[ListPrice] [money] NULL,
	[Size] [nvarchar](5) NULL,
	[SizeUnitMeasureCode] [nchar](3) NULL,
	[WeightUnitMeasureCode] [nchar](3) NULL,
	[Weight] [decimal](8, 2) NULL,
	[DaysToManufacture] [int] NULL,
	[ProductLine] [nchar](2) NULL,
	[Class] [nchar](2) NULL,
	[Style] [nchar](2) NULL,
	[ProductSubcategoryID] [int] NULL,
	[ProductModelID] [int] NULL,
	[SellStartDate] [datetime] NULL,
	[SellEndDate] [datetime] NULL,
	[DiscontinuedDate] [datetime] NULL,
	[rowguid] [uniqueidentifier] NULL,
	[ModifiedDate] [datetime] NULL,
 CONSTRAINT [PK_Product_ProductID] PRIMARY KEY CLUSTERED 
([ProductID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
)ON [PRIMARY]
GO
/*
INSERT INTO dbo.Product
SELECT * FROM AdventureWorks.Production.Product
GO
*/

IF EXISTS (SELECT * FROM sys.tables WHERE [name] = 'ProductModel')
DROP TABLE ProductModel
CREATE TABLE [dbo].[ProductModel](
	[ProductModelID] [int] NOT NULL,
	[Name] [nvarchar] (50) NULL,
	[CatalogDescription] [xml] NULL,
	[Instructions] [xml] NULL,
	[rowguid] [uniqueidentifier] ROWGUIDCOL  NULL,
	[ModifiedDate] [datetime] NULL,
 CONSTRAINT [PK_ProductModel_ProductModelID] PRIMARY KEY CLUSTERED 
([ProductModelID] ASC)
WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
/*
INSERT INTO ProductModel
SELECT * FROM AdventureWorks.Production.ProductModel
GO
*/

/*Table Data*/
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (1,'Adjustable Race','AR-5381',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'694215B7-08F7-4C0D-ACB1-D734BA44C0C8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (2,'Bearing Ball','BA-8327',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'58AE3C20-4F3A-4749-A7D4-D568806CC537','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (3,'BB Ball Bearing','BE-2349',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9C21AED2-5BFA-4F18-BCB8-F11638DC2E4E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (4,'Headset Ball Bearings','BE-2908',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'ECFED6CB-51FF-49B5-B06C-7D8AC834DB8B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (316,'Blade','BL-2036',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E73E9750-603B-4131-89F5-3DD15ED5FF80','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (317,'LL Crankarm','CA-5965',0,0,'Black',500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3C9D10B7-A6B2-4774-9963-C19DCEE72FEA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (318,'ML Crankarm','CA-6738',0,0,'Black',500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EABB9A92-FA07-4EAB-8955-F0517B4A4CA7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (319,'HL Crankarm','CA-7457',0,0,'Black',500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7D3FD384-4F29-484B-86FA-4206E276FE58','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (320,'Chainring Bolts','CB-2903',0,0,'Silver',1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7BE38E48-B7D6-4486-888E-F53C26735101','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (321,'Chainring Nut','CN-6137',0,0,'Silver',1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3314B1D7-EF69-4431-B6DD-DC75268BD5DF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (322,'Chainring','CR-7833',0,0,'Black',1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F0AC2C4D-1A1F-4E3C-B4D9-68AEA0EC1CE4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (323,'Crown Race','CR-9981',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'51A32CA6-65A1-4C31-AF2B-D9E4F5D631D4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (324,'Chain Stays','CS-2812',1,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'FE0678ED-AEF2-4C58-A450-8151CC24DDD8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (325,'Decal 1','DC-8732',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'05CE123C-A402-478E-AE9B-75D7727AEAAD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (326,'Decal 2','DC-9824',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A56851F9-1CD7-4E2F-8779-2E773E1B5209','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (327,'Down Tube','DT-2377',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1DAD47DD-E259-42B8-B8B4-15A0B7D21B2F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (328,'Mountain End Caps','EC-M092',1,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'6070B1EA-59B7-4F8B-950F-2BE07D00449D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (329,'Road End Caps','EC-R098',1,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'88399D13-719E-4545-81D6-F0650F372FA2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (330,'Touring End Caps','EC-T209',1,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'6903CE24-D0CE-4191-9198-4231DE37A929','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (331,'Fork End','FE-3760',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'C91D602E-DA52-43D2-BD7E-EB110A9392B9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (332,'Freewheel','FH-2981',0,0,'Silver',500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D864879A-E8B1-4F7B-BAFA-1F136089C2C8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (341,'Flat Washer 1','FW-1000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A3F2FA3A-22E1-43D8-A131-A9B89C32D8EA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (342,'Flat Washer 6','FW-1200',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'331ADDEC-E9B9-4A7E-9324-42069C2DCDC4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (343,'Flat Washer 2','FW-1400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'84A3473E-AE26-4A21-81B9-60BB418A79B2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (344,'Flat Washer 9','FW-3400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0AE4CE60-5242-48F5-ADA1-3013FF45F969','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (345,'Flat Washer 4','FW-3800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2C1C58B4-234C-4B3A-8C8E-84524AC05EEA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (346,'Flat Washer 3','FW-5160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'590C2C3F-A8B6-42B5-9412-D655E37F0EAE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (347,'Flat Washer 8','FW-5800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1B73F5FE-AB85-49FC-99AD-0500CEBDA91D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (348,'Flat Washer 5','FW-7160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D182CF18-4DDF-429B-A0DF-DE1CFC92622D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (349,'Flat Washer 7','FW-9160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7E55F64D-EA3C-45FF-BE72-F7F7B9D61A79','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (350,'Fork Crown','FC-3654',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1CBFA85B-5C9B-4B58-9C17-95238215D926','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (351,'Front Derailleur Cage','FC-3982',0,0,'Silver',800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'01C901E3-4323-48ED-AB9E-9BFDA28BDEF6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (352,'Front Derailleur Linkage','FL-2301',0,0,'Silver',800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'88ED2E08-E775-4915-B506-831600B773FD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (355,'Guide Pulley','GP-0982',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'6A89205B-90C3-4997-8C63-BC6A5EBC752D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (356,'LL Grip Tape','GT-0820',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'32C82181-1969-4660-AE04-A02D51994EC1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (357,'ML Grip Tape','GT-1209',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'09343E22-2494-4279-9F32-5D961A0FBFEA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (358,'HL Grip Tape','GT-2908',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8E5B2BF7-81DD-4454-B75E-D9AE2A6FBD26','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (359,'Thin-Jam Hex Nut 9','HJ-1213',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A63AFF3C-4143-4016-BC99-D3F80EC1ADE5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (360,'Thin-Jam Hex Nut 10','HJ-1220',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A1AE0C6D-92A5-4FDA-B33B-1301E83EFE5B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (361,'Thin-Jam Hex Nut 1','HJ-1420',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E33E8C4C-282A-4D1F-91E7-E9969CF7134F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (362,'Thin-Jam Hex Nut 2','HJ-1428',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A992684F-4642-4856-A817-2C0740AE8C55','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (363,'Thin-Jam Hex Nut 15','HJ-3410',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B9D9A30D-CB07-422D-A312-F0535575337E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (364,'Thin-Jam Hex Nut 16','HJ-3416',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0EC8F653-24C9-41B6-86F5-39C1789DB580','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (365,'Thin-Jam Hex Nut 5','HJ-3816',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'94506C9D-5991-46A7-82EA-00E05D8D9B9C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (366,'Thin-Jam Hex Nut 6','HJ-3824',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'71E984C6-1D11-4CF2-BAEE-6C8DF494BDAD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (367,'Thin-Jam Hex Nut 3','HJ-5161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EFC09CDB-ECD5-4DB5-9E27-277DDA6D7F50','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (368,'Thin-Jam Hex Nut 4','HJ-5162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0A0C93AA-D06C-48AA-99EB-20F2C8A6D6C4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (369,'Thin-Jam Hex Nut 13','HJ-5811',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A2728648-9517-4DEC-8606-D7D98ECD1E91','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (370,'Thin-Jam Hex Nut 14','HJ-5818',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0A7AD37C-3696-4844-8633-9FDDCD5FCEFC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (371,'Thin-Jam Hex Nut 7','HJ-7161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'ACBB1DE1-680C-4034-A8C5-3C6B01E57AA7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (372,'Thin-Jam Hex Nut 8','HJ-7162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A0DA8F8F-45FB-4E62-AB14-AA229087DE1E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (373,'Thin-Jam Hex Nut 12','HJ-9080',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DB99CBCD-F18D-4979-8DCF-1012F3B1CB15','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (374,'Thin-Jam Hex Nut 11','HJ-9161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EC2E54F5-9D07-4C26-B969-40F835395BE3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (375,'Hex Nut 5','HN-1024',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F2F3A14C-DF15-4957-966D-55E5FCAD1161','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (376,'Hex Nut 6','HN-1032',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E73E44DD-F0B7-45D4-9066-E49F1B1FE7D0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (377,'Hex Nut 16','HN-1213',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2B2A5641-BFFE-4079-B9F0-8BF355BC3996','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (378,'Hex Nut 17','HN-1220',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F70BBECD-5BE7-4EE9-A9E7-15786E622BA9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (379,'Hex Nut 7','HN-1224',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'BA3631D1-33D6-4A2F-8413-758BFDA6F9C2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (380,'Hex Nut 8','HN-1420',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B478B33A-1FD5-4DB6-B99A-EB3B2A7C1623','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (381,'Hex Nut 9','HN-1428',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DA46D979-59DF-456D-B5AE-E7E89FC589DF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (382,'Hex Nut 22','HN-3410',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2F457404-197D-4DDF-9868-A3AAD1B32D6B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (383,'Hex Nut 23','HN-3416',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5F02449E-96E5-4FC8-ADE0-8A9A7F533624','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (384,'Hex Nut 12','HN-3816',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'32C97696-7C3D-4793-A54B-3D73200BADBC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (385,'Hex Nut 13','HN-3824',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8F0902D0-274D-4A4B-8FDE-E37F53B2AB29','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (386,'Hex Nut 1','HN-4402',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'57456F8C-CB78-45EC-B9B8-21A9BE5C12F5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (387,'Hex Nut 10','HN-5161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'955811B4-2F17-48F0-A8B4-0C96CBA4AA6D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (388,'Hex Nut 11','HN-5162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7D4BAD17-374F-4281-9AE5-49ABC3FE585D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (389,'Hex Nut 2','HN-5400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'17C4B7BA-8574-4EC7-BD3B-7A51ABA61F69','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (390,'Hex Nut 20','HN-5811',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B4E990B7-B3F7-4F97-8F98-CE373833ADB4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (391,'Hex Nut 21','HN-5818',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'433EE702-E028-4630-895C-8CDBD0F1FD89','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (392,'Hex Nut 3','HN-6320',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EE76FAE0-161E-409C-A6F5-837B5B8B344D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (393,'Hex Nut 14','HN-7161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EB10B88C-5351-4C06-AF51-116BAA48A2C8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (394,'Hex Nut 15','HN-7162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'35E28755-E8F0-47BE-A8BE-A20836DBE28D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (395,'Hex Nut 4','HN-8320',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'69AB8D5E-6101-4203-81B1-794E923782EA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (396,'Hex Nut 18','HN-9161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'39D42384-66F6-4CCD-B471-0589FC3FC576','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (397,'Hex Nut 19','HN-9168',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B63F827E-9055-4678-9E90-4FFD8D06D4D4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (398,'Handlebar Tube','HT-2981',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9F88C58E-5CFA-46C9-8994-DA4F3FFE92ED','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (399,'Head Tube','HT-8019',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B047C048-B4FB-4F80-94BC-C5FC00A6F77F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (400,'LL Hub','HU-6280',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AB332DDA-DDA5-44AD-8C50-34FFACEFFA8E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (401,'HL Hub','HU-8998',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D59403A3-D19E-4803-BDA2-B436A6416FDA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (402,'Keyed Washer','KW-4091',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'43024784-2741-4CAB-A6DC-8050CE507F2E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (403,'External Lock Washer 3','LE-1000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'763412F0-6D53-43E2-B371-DCBED69F5E98','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (404,'External Lock Washer 4','LE-1200',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'89B6E84F-5C08-4CD9-B803-01F2CE24E417','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (405,'External Lock Washer 9','LE-1201',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3330A721-E8CB-4E67-8D27-300DB68C2395','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (406,'External Lock Washer 5','LE-1400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'39314098-768B-49F9-A777-AF2E3BB06B17','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (407,'External Lock Washer 7','LE-3800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'93F7BC73-BD22-45A0-9F2E-A11932342E6B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (408,'External Lock Washer 6','LE-5160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DC5F4CB0-A599-42CD-A96F-E9F01BC1DACC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (409,'External Lock Washer 1','LE-6000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'802B7687-BC74-43F8-98AE-2112166FACA7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (410,'External Lock Washer 8','LE-7160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'02C48826-21AD-41F3-85A6-BC9A85A4DCE4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (411,'External Lock Washer 2','LE-8000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'502A2A3D-CD72-43AD-8FB6-77505187EDF4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (412,'Internal Lock Washer 3','LI-1000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F1168C45-E4D2-4C37-ADAD-B76EAF402B71','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (413,'Internal Lock Washer 4','LI-1200',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7F7413BB-BAD2-47E4-9BC4-D98B194BE35D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (414,'Internal Lock Washer 9','LI-1201',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'4F040109-8332-4FCF-8084-57E6D8C49283','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (415,'Internal Lock Washer 5','LI-1400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0C02F2CC-BDB4-4794-A4F9-0EB33F7545C2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (416,'Internal Lock Washer 7','LI-3800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3C2AC5BC-3F49-4FA4-8340-BC4CDA983F46','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (417,'Internal Lock Washer 6','LI-5160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7F175DFE-1669-4EE9-8EEB-7B55FCE9961C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (418,'Internal Lock Washer 10','LI-5800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'C8323EEC-BDB2-4933-B3C6-24287638AD56','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (419,'Internal Lock Washer 1','LI-6000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'71F8232D-2B59-41AC-99A1-F5EA197671B5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (420,'Internal Lock Washer 8','LI-7160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E2F03586-02E8-4CD9-A342-1A8D65D393BD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (421,'Internal Lock Washer 2','LI-8000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'97741A88-92A1-4E72-B0AA-BCB198A1C378','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (422,'Thin-Jam Lock Nut 9','LJ-1213',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7DA2613B-3347-4072-A1DC-943ADA161D7F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (423,'Thin-Jam Lock Nut 10','LJ-1220',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A88F15BE-2719-4741-93A4-2D96EF3712EB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (424,'Thin-Jam Lock Nut 1','LJ-1420',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'48461E5D-D58A-47E5-8BA3-CE4430FCA611','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (425,'Thin-Jam Lock Nut 2','LJ-1428',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'36187EB6-AD84-47B7-A55E-2941D3435FE2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (426,'Thin-Jam Lock Nut 15','LJ-3410',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'99215648-AFE8-4556-BC80-B6C62AE74FC8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (427,'Thin-Jam Lock Nut 16','LJ-3416',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B4FC4C32-049C-417F-BBB0-F19CDFD64252','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (428,'Thin-Jam Lock Nut 5','LJ-3816',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A57B7915-2E65-49DE-87BA-ACD007C55ADB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (429,'Thin-Jam Lock Nut 6','LJ-3824',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5ABD940C-D61F-4108-8312-0EA97E469613','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (430,'Thin-Jam Lock Nut 3','LJ-5161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9883496F-4785-4BFC-8AF3-C357347B9F89','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (431,'Thin-Jam Lock Nut 4','LJ-5162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8C5EE683-D93C-4F25-9454-22FAA4C31365','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (432,'Thin-Jam Lock Nut 13','LJ-5811',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'38E4A447-3D3C-4087-ABAD-97F006525B52','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (433,'Thin-Jam Lock Nut 14','LJ-5818',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DCE24B6C-76D8-4934-A4F6-C934364943EA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (434,'Thin-Jam Lock Nut 7','LJ-7161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'344AD07C-CCA5-4374-A3F3-8A7E0A1D9916','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (435,'Thin-Jam Lock Nut 8','LJ-7162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B2508CF2-C64F-493D-9DB4-0D6601AF1F73','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (436,'Thin-Jam Lock Nut 12','LJ-9080',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5D3E589F-4584-406B-B9CC-3C8C060CB9A5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (437,'Thin-Jam Lock Nut 11','LJ-9161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'64169A28-161C-4737-B724-F42FFD99DE80','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (438,'Lock Nut 5','LN-1024',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'EB4C1D34-4816-4130-BB30-07B4DE4072B6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (439,'Lock Nut 6','LN-1032',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'98CCBB38-4683-486E-BBFE-CBBE4EA63C03','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (440,'Lock Nut 16','LN-1213',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'BBFD88F8-28C5-44EE-B625-52E882393DFC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (441,'Lock Nut 17','LN-1220',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'92DC4BA8-A052-45DF-83EC-226F050F876B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (442,'Lock Nut 7','LN-1224',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D583D825-C707-4529-B6F2-ABFFA21B81EC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (443,'Lock Nut 8','LN-1420',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E91C3DC2-C99B-4D01-8108-5DDE3C87830A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (444,'Lock Nut 9','LN-1428',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'06534A20-4C00-4824-8BBA-B4E3A5724D93','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (445,'Lock Nut 22','LN-3410',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1E4FA4EC-367E-4D8D-88B4-6CD34D1CFB89','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (446,'Lock Nut 23','LN-3416',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AFA814C8-8EC8-49DB-9FEE-A291197A8FE9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (447,'Lock Nut 12','LN-3816',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9A751F85-7130-4562-9F22-DB9CAB6E5BBC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (448,'Lock Nut 13','LN-3824',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'06BE8347-45C1-4C40-AFCB-6AB34AD135FB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (449,'Lock Nut 1','LN-4400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1DC29704-E0E0-4EF5-B581-4A524730C448','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (450,'Lock Nut 10','LN-5161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'612C26C7-6018-4050-B628-8B2D2E6841FA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (451,'Lock Nut 11','LN-5162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5BCC4558-6C16-48F1-92F0-FD2EEFB17306','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (452,'Lock Nut 2','LN-5400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'53AD147D-C16D-4A8C-B086-625A31405574','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (453,'Lock Nut 20','LN-5811',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2749030E-49B7-4B24-8D47-FBCF194ABA38','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (454,'Lock Nut 21','LN-5818',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E10A7B34-87F5-42CD-88B3-27A3D8E16B18','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (455,'Lock Nut 3','LN-6320',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AA5071EB-2145-4D08-9D33-B9D2BA9E1493','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (456,'Lock Nut 14','LN-7161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1E96B03D-DC07-4A98-BC24-BF5B24C393E5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (457,'Lock Nut 15','LN-7162',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'CE04DE2B-4ECA-4203-A108-B7D92FF0E96E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (458,'Lock Nut 4','LN-8320',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'41BD9389-8B22-4A35-9A2C-233D39ADA7EA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (459,'Lock Nut 19','LN-9080',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5986504B-22A0-4E74-A137-C7CF99A8216F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (460,'Lock Nut 18','LN-9161',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A420963F-92FD-4CD4-8531-6926E4162C41','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (461,'Lock Ring','LR-2398',0,0,'Silver',1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AECA59DA-B61C-4976-8316-97E14CD4EFF1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (462,'Lower Head Race','LR-8520',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DBB962BF-0603-4095-959B-5BA9C74FBD32','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (463,'Lock Washer 4','LW-1000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A3EE3BC5-73C5-45F3-A952-9991D038DD9C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (464,'Lock Washer 5','LW-1200',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'ECAED08D-2CF5-4D81-A4ED-8369E25AF227','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (465,'Lock Washer 10','LW-1201',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A2212BAB-AF58-41A5-A659-A6141C8967CA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (466,'Lock Washer 6','LW-1400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9092F2E1-3637-4669-8565-55404A55750E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (467,'Lock Washer 13','LW-3400',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3CB31F4A-C61C-408C-BE1E-48BEE412E511','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (468,'Lock Washer 8','LW-3800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'900D26E6-21A0-427D-B43C-173F6DCB2045','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (469,'Lock Washer 1','LW-4000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5402EA37-29DF-47FF-9FC7-867D60594C48','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (470,'Lock Washer 7','LW-5160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'99357255-E66B-458C-AB2E-6F68EF5452D2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (471,'Lock Washer 12','LW-5800',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7BC9D58E-3E62-481F-8343-BEB0883B3ECF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (472,'Lock Washer 2','LW-6000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5F201424-9E6A-4F8D-9C2C-30777E27D64F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (473,'Lock Washer 9','LW-7160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F9426FB2-1E68-464E-BF32-615026E0249E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (474,'Lock Washer 3','LW-8000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AC007B7F-73B7-4623-8150-02444C5EC023','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (475,'Lock Washer 11','LW-9160',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'639D8448-B427-47B1-9E5B-0E5090A27632','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (476,'Metal Angle','MA-7075',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'E876E239-7EC2-45C8-BA4B-B9CEACB379A6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (477,'Metal Bar 1','MB-2024',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8B5429CE-7876-44B3-9332-BAF78A238B36','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (478,'Metal Bar 2','MB-6061',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2A14F60E-3827-49BA-AF13-466DBC30C5BA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (479,'Metal Plate 2','MP-2066',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'0773A2C9-F47F-429E-814A-25B2E08C128A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (480,'Metal Plate 1','MP-2503',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'242389BE-DDE0-42A1-85D9-F99FDC981336','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (481,'Metal Plate 3','MP-4960',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8B7E90E5-7785-455E-BC7C-E962F18C6848','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (482,'Metal Sheet 2','MS-0253',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8BB96DFB-23AA-4877-9C5E-866BB18FACC7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (483,'Metal Sheet 3','MS-1256',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9074E00D-005B-450E-9C92-6667782E8108','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (484,'Metal Sheet 7','MS-1981',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'A9539885-0CEE-4AA0-9072-8DB1D34A16DB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (485,'Metal Sheet 4','MS-2259',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3CB3CF7D-AB8E-44A3-B7E9-73149F5EC29F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (486,'Metal Sheet 5','MS-2341',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'2A2C555D-328D-4299-BD83-591D0762DF62','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (487,'Metal Sheet 6','MS-2348',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'64844011-A1C3-4F8F-9CAA-9C8D214ECC12','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (488,'Metal Sheet 1','MS-6061',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'3B2FEBC6-C76C-4A56-9CF7-8AF5B76E24EE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (489,'Metal Tread Plate','MT-1000',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D2177B6C-3352-43F0-9A41-719754DD280C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (490,'LL Nipple','NI-4127',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'88310F73-AB0A-41A2-8597-936F192B7D12','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (491,'HL Nipple','NI-9522',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'88A7B897-6FF5-4CA2-B68A-6EA0E86F92B9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (492,'Paint - Black','PA-187B',0,0,NULL,60,45,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'DF20E514-3D47-491B-9454-0911EC3F7D29','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (493,'Paint - Red','PA-361R',0,0,NULL,60,45,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'4C568357-5D21-4AD4-BB85-BB5519B3B50C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (494,'Paint - Silver','PA-529S',0,0,NULL,60,45,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'FA81E47D-7333-49C2-809B-308171CA2FB1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (495,'Paint - Blue','PA-632U',0,0,NULL,60,45,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'25A73761-AE90-49D3-8D1D-DD7858DB4704','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (496,'Paint - Yellow','PA-823Y',0,0,NULL,60,45,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1C8ADB43-9FE8-44A6-B949-8AF33CE9486E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (497,'Pinch Bolt','PB-6109',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F1694C24-DFAB-4C92-BC66-6E717DB24EA8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (504,'Cup-Shaped Race','RA-2345',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'874C800E-334D-4A3C-8D3A-1E872D5B2A1B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (505,'Cone-Shaped Race','RA-7490',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'35CE3995-9DD2-40E2-98B8-275931AC2D76','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (506,'Reflector','RF-9198',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1C850499-38ED-4C2D-8665-7EDB6A7CE93D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (507,'LL Mountain Rim','RM-M464',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',435.00,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'B2CC7DFB-783D-4587-88C0-2712A538A5B2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (508,'ML Mountain Rim','RM-M692',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',450.00,0,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'733FD04D-322F-44F5-BEEC-F326189D1CE6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (509,'HL Mountain Rim','RM-M823',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',400.00,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9FA4A3B5-D396-48D4-ADFC-B573BC4A800A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (510,'LL Road Rim','RM-R436',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',445.00,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'C2770757-B258-4EEC-A811-6856FAF87437','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (511,'ML Road Rim','RM-R600',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',450.00,0,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'80108059-0002-4253-A805-53A2324C33A4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (512,'HL Road Rim','RM-R800',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',400.00,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'CD9B5C44-FB31-4E0F-9905-3B2086966CC5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (513,'Touring Rim','RM-T801',0,0,NULL,800,600,0.00,0.00,NULL,NULL,'G  ',460.00,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'4852DB13-308A-4893-AAFA-390A0DFE9F12','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (514,'LL Mountain Seat Assembly','SA-M198',1,0,NULL,500,375,98.77,133.34,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'FCFC0A4F-4563-4E0B-BFF4-5DDCFE3A9273','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (515,'ML Mountain Seat Assembly','SA-M237',1,0,NULL,500,375,108.99,147.14,NULL,NULL,NULL,NULL,1,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D3C8AE4C-A1BE-448D-BF58-6ECBF36AFA0B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (516,'HL Mountain Seat Assembly','SA-M687',1,0,NULL,500,375,145.87,196.92,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9E18ADAB-B9C7-45B1-BD95-1805EC4F297D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (517,'LL Road Seat Assembly','SA-R127',1,0,NULL,500,375,98.77,133.34,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F5A30B8D-F35B-43F2-83A0-F7F6B51F6241','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (518,'ML Road Seat Assembly','SA-R430',1,0,NULL,500,375,108.99,147.14,NULL,NULL,NULL,NULL,1,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AD109395-FDA9-4C2A-96F1-515CCDE3D9F4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (519,'HL Road Seat Assembly','SA-R522',1,0,NULL,500,375,145.87,196.92,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'7B52EE2A-7100-4A39-A0AF-C89012DA6EF8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (520,'LL Touring Seat Assembly','SA-T467',1,0,NULL,500,375,98.77,133.34,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AF3D83BA-4B8E-4072-817F-E6B095A1C879','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (521,'ML Touring Seat Assembly','SA-T612',1,0,NULL,500,375,108.99,147.14,NULL,NULL,NULL,NULL,1,NULL,'M ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'85B9A3DE-000C-4351-9494-05796689C216','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (522,'HL Touring Seat Assembly','SA-T872',1,0,NULL,500,375,145.87,196.92,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'8C471BCA-A735-4087-AD50-90EDE0AC1A1B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (523,'LL Spindle/Axle','SD-2342',0,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D2BD1F55-2CD4-4998-89FA-28FF2E28DE2C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (524,'HL Spindle/Axle','SD-9872',0,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'6CE0661D-BA1F-4012-B785-55165B3B241A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (525,'LL Shell','SH-4562',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,'L ',NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'AE7BCDA7-E836-4F68-9E61-745F27F9AA3E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (526,'HL Shell','SH-9312',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'D215A3AE-AAF2-4CB0-9D20-3758AAD078E2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (527,'Spokes','SK-9283',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'5AABB729-343B-4084-A235-CCB3DA9F29E7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (528,'Seat Lug','SL-0931',0,0,NULL,1000,750,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'4A898B1E-9A3B-4BEB-9873-A7465934051A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (529,'Stem','SM-9087',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'1173306E-B616-4C4A-B715-4E0A483BA2B5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (530,'Seat Post','SP-2981',0,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'9B4CEB84-4E84-43F3-B326-9B7F22905363','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (531,'Steerer','SR-2098',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'F3B140A1-B139-4BB5-B144-1B7CBBEE6C9A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (532,'Seat Stays','SS-2985',1,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'20C2C611-DFFC-49B5-99CF-D89BDD3A91CE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (533,'Seat Tube','ST-9828',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'41F5388B-7253-4002-BCC6-B2A50920D11F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (534,'Top Tube','TO-2301',1,0,NULL,500,375,0.00,0.00,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'4C0BAD8E-066B-46B8-BFE9-DA61539606E8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (535,'Tension Pulley','TP-0923',0,0,NULL,800,600,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'13DF62B2-8A7B-47D5-9084-F1172C4779E4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (679,'Rear Derailleur Cage','RC-0291',0,0,'Silver',500,375,0.00,0.00,NULL,NULL,NULL,NULL,0,NULL,NULL,NULL,NULL,NULL,'Jun  1 1998 12:00AM',NULL,NULL,'912B03EA-4447-48C8-85DA-09B80AB26340','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (680,'HL Road Frame - Black, 58','FR-R92B-58',1,1,'Black',500,375,1059.31,1431.50,'58','CM ','LB ',2.24,1,'R ','H ','U ',14,6,'Jun  1 1998 12:00AM',NULL,NULL,'43DD68D6-14A4-461F-9069-55309D90EA7E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (706,'HL Road Frame - Red, 58','FR-R92R-58',1,1,'Red',500,375,1059.31,1431.50,'58','CM ','LB ',2.24,1,'R ','H ','U ',14,6,'Jun  1 1998 12:00AM',NULL,NULL,'9540FF17-2712-4C90-A3D1-8CE5568B2462','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (707,'Sport-100 Helmet, Red','HL-U509-R',0,1,'Red',4,3,13.09,34.99,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,31,33,'Jul  1 2001 12:00AM',NULL,NULL,'2E1EF41A-C08A-4FF6-8ADA-BDE58B64A712','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (708,'Sport-100 Helmet, Black','HL-U509',0,1,'Black',4,3,13.09,34.99,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,31,33,'Jul  1 2001 12:00AM',NULL,NULL,'A25A44FB-C2DE-4268-958F-110B8D7621E2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (709,'Mountain Bike Socks, M','SO-B909-M',0,1,'White',4,3,3.40,9.50,'M',NULL,NULL,NULL,0,'M ',NULL,'U ',23,18,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'18F95F47-1540-4E02-8F1F-CC1BCB6828D0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (710,'Mountain Bike Socks, L','SO-B909-L',0,1,'White',4,3,3.40,9.50,'L',NULL,NULL,NULL,0,'M ',NULL,'U ',23,18,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'161C035E-21B3-4E14-8E44-AF508F35D80A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (711,'Sport-100 Helmet, Blue','HL-U509-B',0,1,'Blue',4,3,13.09,34.99,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,31,33,'Jul  1 2001 12:00AM',NULL,NULL,'FD7C0858-4179-48C2-865B-ABD5DFC7BC1D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (712,'AWC Logo Cap','CA-1098',0,1,'Multi',4,3,6.92,8.99,NULL,NULL,NULL,NULL,0,'S ',NULL,'U ',19,2,'Jul  1 2001 12:00AM',NULL,NULL,'B9EDE243-A6F4-4629-B1D4-FFE1AEDC6DE7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (713,'Long-Sleeve Logo Jersey, S','LJ-0192-S',0,1,'Multi',4,3,38.49,49.99,'S',NULL,NULL,NULL,0,'S ',NULL,'U ',21,11,'Jul  1 2001 12:00AM',NULL,NULL,'FD449C82-A259-4FAE-8584-6CA0255FAF68','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (714,'Long-Sleeve Logo Jersey, M','LJ-0192-M',0,1,'Multi',4,3,38.49,49.99,'M',NULL,NULL,NULL,0,'S ',NULL,'U ',21,11,'Jul  1 2001 12:00AM',NULL,NULL,'6A290063-A0CF-432A-8110-2EA0FDA14308','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (715,'Long-Sleeve Logo Jersey, L','LJ-0192-L',0,1,'Multi',4,3,38.49,49.99,'L',NULL,NULL,NULL,0,'S ',NULL,'U ',21,11,'Jul  1 2001 12:00AM',NULL,NULL,'34CF5EF5-C077-4EA0-914A-084814D5CBD5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (716,'Long-Sleeve Logo Jersey, XL','LJ-0192-X',0,1,'Multi',4,3,38.49,49.99,'XL',NULL,NULL,NULL,0,'S ',NULL,'U ',21,11,'Jul  1 2001 12:00AM',NULL,NULL,'6EC47EC9-C041-4DDA-B686-2125D539CE9B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (717,'HL Road Frame - Red, 62','FR-R92R-62',1,1,'Red',500,375,868.63,1431.50,'62','CM ','LB ',2.30,1,'R ','H ','U ',14,6,'Jul  1 2001 12:00AM',NULL,NULL,'052E4F8B-0A2A-46B2-9F42-10FEBCFAE416','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (718,'HL Road Frame - Red, 44','FR-R92R-44',1,1,'Red',500,375,868.63,1431.50,'44','CM ','LB ',2.12,1,'R ','H ','U ',14,6,'Jul  1 2001 12:00AM',NULL,NULL,'A88D3B54-2CAE-43F2-8C6E-EA1D97B46A7C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (719,'HL Road Frame - Red, 48','FR-R92R-48',1,1,'Red',500,375,868.63,1431.50,'48','CM ','LB ',2.16,1,'R ','H ','U ',14,6,'Jul  1 2001 12:00AM',NULL,NULL,'07BEFC9A-7634-402B-B234-D7797733BAAF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (720,'HL Road Frame - Red, 52','FR-R92R-52',1,1,'Red',500,375,868.63,1431.50,'52','CM ','LB ',2.20,1,'R ','H ','U ',14,6,'Jul  1 2001 12:00AM',NULL,NULL,'FCFEA68F-310E-4E6E-9F99-BB17D011EBAE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (721,'HL Road Frame - Red, 56','FR-R92R-56',1,1,'Red',500,375,868.63,1431.50,'56','CM ','LB ',2.24,1,'R ','H ','U ',14,6,'Jul  1 2001 12:00AM',NULL,NULL,'56C85873-4993-41B4-8096-1067CFD7E4BD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (722,'LL Road Frame - Black, 58','FR-R38B-58',1,1,'Black',500,375,204.63,337.22,'58','CM ','LB ',2.46,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'2140F256-F705-4D67-975D-32DE03265838','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (723,'LL Road Frame - Black, 60','FR-R38B-60',1,1,'Black',500,375,204.63,337.22,'60','CM ','LB ',2.48,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'AA95E2A5-E7C4-4B74-B1EA-B52EE3B51537','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (724,'LL Road Frame - Black, 62','FR-R38B-62',1,1,'Black',500,375,204.63,337.22,'62','CM ','LB ',2.50,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'5247BE33-50BF-4527-8A30-A39AAE500A8E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (725,'LL Road Frame - Red, 44','FR-R38R-44',1,1,'Red',500,375,187.16,337.22,'44','CM ','LB ',2.32,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'137D319D-44AD-42B2-AB61-60B9CE52B5F2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (726,'LL Road Frame - Red, 48','FR-R38R-48',1,1,'Red',500,375,187.16,337.22,'48','CM ','LB ',2.36,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'35213547-275F-4767-805D-C8A4B8E13745','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (727,'LL Road Frame - Red, 52','FR-R38R-52',1,1,'Red',500,375,187.16,337.22,'52','CM ','LB ',2.40,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'C455E0B3-D716-419D-ABF0-7E03EFDD2E26','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (728,'LL Road Frame - Red, 58','FR-R38R-58',1,1,'Red',500,375,187.16,337.22,'58','CM ','LB ',2.46,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'799A56FF-5AD2-41B3-BFAC-528B477AD129','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (729,'LL Road Frame - Red, 60','FR-R38R-60',1,1,'Red',500,375,187.16,337.22,'60','CM ','LB ',2.48,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'1784BB14-D1F5-4B24-92DA-9127AD179302','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (730,'LL Road Frame - Red, 62','FR-R38R-62',1,1,'Red',500,375,187.16,337.22,'62','CM ','LB ',2.50,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'7E73AA1F-8569-4D87-9F80-AC2E513E0803','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (731,'ML Road Frame - Red, 44','FR-R72R-44',1,1,'Red',500,375,352.14,594.83,'44','CM ','LB ',2.22,1,'R ','M ','U ',14,16,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'459E041C-3234-409E-B4CD-81728F8A2398','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (732,'ML Road Frame - Red, 48','FR-R72R-48',1,1,'Red',500,375,352.14,594.83,'48','CM ','LB ',2.26,1,'R ','M ','U ',14,16,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'B673189C-C042-413B-8194-73BC44B0492C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (733,'ML Road Frame - Red, 52','FR-R72R-52',1,1,'Red',500,375,352.14,594.83,'52','CM ','LB ',2.30,1,'R ','M ','U ',14,16,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'55EA276B-82D8-4CCB-9AB1-9B1B75B15A83','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (734,'ML Road Frame - Red, 58','FR-R72R-58',1,1,'Red',500,375,352.14,594.83,'58','CM ','LB ',2.36,1,'R ','M ','U ',14,16,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'DF4CE1E2-BA9A-4657-B999-CCFA6C55D9C1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (735,'ML Road Frame - Red, 60','FR-R72R-60',1,1,'Red',500,375,352.14,594.83,'60','CM ','LB ',2.38,1,'R ','M ','U ',14,16,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'B2E48E8C-63A5-469A-BA4C-4F5EBB1104A4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (736,'LL Road Frame - Black, 44','FR-R38B-44',1,1,'Black',500,375,204.63,337.22,'44','CM ','LB ',2.32,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'C9967889-F490-4A66-943A-BCE432E938D8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (737,'LL Road Frame - Black, 48','FR-R38B-48',1,1,'Black',500,375,204.63,337.22,'48','CM ','LB ',2.36,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'3B5F29B6-A441-4FF7-A0FA-FAD10E2CEB4C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (738,'LL Road Frame - Black, 52','FR-R38B-52',1,1,'Black',500,375,204.63,337.22,'52','CM ','LB ',2.40,1,'R ','L ','U ',14,9,'Jul  1 2001 12:00AM',NULL,NULL,'18FC5D72-A012-4DC7-BB35-0D01A84D0219','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (739,'HL Mountain Frame - Silver, 42','FR-M94S-42',1,1,'Silver',500,375,747.20,1364.50,'42','CM ','LB ',2.72,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'8AE32663-8D6F-457D-8343-5B181FEC43A7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (740,'HL Mountain Frame - Silver, 44','FR-M94S-44',1,1,'Silver',500,375,706.81,1364.50,'44','CM ','LB ',2.76,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'1909C60C-C490-411D-B3E6-12DDD7832482','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (741,'HL Mountain Frame - Silver, 48','FR-M94S-52',1,1,'Silver',500,375,706.81,1364.50,'48','CM ','LB ',2.80,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'B181EC1F-CA20-4724-B2EB-15F3E455142E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (742,'HL Mountain Frame - Silver, 46','FR-M94S-46',1,1,'Silver',500,375,747.20,1364.50,'46','CM ','LB ',2.84,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'A189D86E-D923-4336-B13D-A5DB6F426540','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (743,'HL Mountain Frame - Black, 42','FR-M94B-42',1,1,'Black',500,375,739.04,1349.60,'42','CM ','LB ',2.72,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'27DB28F8-5AB8-4091-B94E-6F1B2D8E7AB0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (744,'HL Mountain Frame - Black, 44','FR-M94B-44',1,1,'Black',500,375,699.09,1349.60,'44','CM ','LB ',2.76,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'CB443286-6B25-409F-A10B-1AD4EEB4BD4E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (745,'HL Mountain Frame - Black, 48','FR-M94B-48',1,1,'Black',500,375,699.09,1349.60,'48','CM ','LB ',2.80,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'1FEE0573-6676-432D-8D6D-41BA9FAA5865','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (746,'HL Mountain Frame - Black, 46','FR-M94B-46',1,1,'Black',500,375,739.04,1349.60,'46','CM ','LB ',2.84,1,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'50ABEBCB-451E-42B9-8DBB-E5C4A34470E9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (747,'HL Mountain Frame - Black, 38','FR-M94B-38',1,1,'Black',500,375,739.04,1349.60,'38','CM ','LB ',2.68,2,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'0C548577-3171-4CE2-B9A0-1ED526849DE8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (748,'HL Mountain Frame - Silver, 38','FR-M94S-38',1,1,'Silver',500,375,747.20,1364.50,'38','CM ','LB ',2.68,2,'M ','H ','U ',12,5,'Jul  1 2001 12:00AM',NULL,NULL,'F246ACAA-A80B-40EC-9208-02EDEF885129','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (749,'Road-150 Red, 62','BK-R93R-62',1,1,'Red',100,75,2171.29,3578.27,'62','CM ','LB ',15.00,4,'R ','H ','U ',2,25,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'BC621E1F-2553-4FDC-B22E-5E44A9003569','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (750,'Road-150 Red, 44','BK-R93R-44',1,1,'Red',100,75,2171.29,3578.27,'44','CM ','LB ',13.77,4,'R ','H ','U ',2,25,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'C19E1136-5DA4-4B40-8758-54A85D7EA494','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (751,'Road-150 Red, 48','BK-R93R-48',1,1,'Red',100,75,2171.29,3578.27,'48','CM ','LB ',14.13,4,'R ','H ','U ',2,25,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'D10B7CC1-455E-435B-A08F-EC5B1C5776E9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (752,'Road-150 Red, 52','BK-R93R-52',1,1,'Red',100,75,2171.29,3578.27,'52','CM ','LB ',14.42,4,'R ','H ','U ',2,25,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'5E085BA0-3CD5-487F-85BB-79ED1C701F23','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (753,'Road-150 Red, 56','BK-R93R-56',1,1,'Red',100,75,2171.29,3578.27,'56','CM ','LB ',14.68,4,'R ','H ','U ',2,25,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'30819B88-F0D3-4E7A-8105-19F6FAC2CEFB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (754,'Road-450 Red, 58','BK-R68R-58',1,1,'Red',100,75,884.71,1457.99,'58','CM ','LB ',17.79,4,'R ','M ','U ',2,28,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'40D5EFFA-C0C4-479F-AF66-5F1BF8ED3BFB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (755,'Road-450 Red, 60','BK-R68R-60',1,1,'Red',100,75,884.71,1457.99,'60','CM ','LB ',17.90,4,'R ','M ','U ',2,28,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'181A90CB-3678-490E-8418-78F73FB5343D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (756,'Road-450 Red, 44','BK-R68R-44',1,1,'Red',100,75,884.71,1457.99,'44','CM ','LB ',16.77,4,'R ','M ','U ',2,28,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'F8B5E26A-3D33-4E39-B500-CC21A133062E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (757,'Road-450 Red, 48','BK-R68R-48',1,1,'Red',100,75,884.71,1457.99,'48','CM ','LB ',17.13,4,'R ','M ','U ',2,28,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'C72C9978-0B04-46B3-9DE6-948FECA1C86E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (758,'Road-450 Red, 52','BK-R68R-52',1,1,'Red',100,75,884.71,1457.99,'52','CM ','LB ',17.42,4,'R ','M ','U ',2,28,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'040A4B7D-4060-4507-AA92-7508B434797E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (759,'Road-650 Red, 58','BK-R50R-58',1,1,'Red',100,75,486.71,782.99,'58','CM ','LB ',19.79,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'6711D6BC-664F-4890-9F69-AF1DE321D055','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (760,'Road-650 Red, 60','BK-R50R-60',1,1,'Red',100,75,486.71,782.99,'60','CM ','LB ',19.90,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'664867E5-4AB3-4783-96F9-42EFDE92F49B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (761,'Road-650 Red, 62','BK-R50R-62',1,1,'Red',100,75,486.71,782.99,'62','CM ','LB ',20.00,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'1DA14E09-6D71-4E2A-9EE9-1BDFDFD8A109','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (762,'Road-650 Red, 44','BK-R50R-44',1,1,'Red',100,75,486.71,782.99,'44','CM ','LB ',18.77,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'F247AAAE-12E3-4048-A37B-CCE4A8999E81','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (763,'Road-650 Red, 48','BK-R50R-48',1,1,'Red',100,75,486.71,782.99,'48','CM ','LB ',19.13,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'3DA5FA6E-9E0F-4896-AC10-948C27F4EB79','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (764,'Road-650 Red, 52','BK-R50R-52',1,1,'Red',100,75,486.71,782.99,'52','CM ','LB ',19.42,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'07CFE1EA-8A37-4D2A-835F-BC8D37E564AF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (765,'Road-650 Black, 58','BK-R50B-58',1,1,'Black',100,75,486.71,782.99,'58','CM ','LB ',19.79,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'74645B12-3CE9-49A6-BD96-2CD814B37420','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (766,'Road-650 Black, 60','BK-R50B-60',1,1,'Black',100,75,486.71,782.99,'60','CM ','LB ',19.90,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'A2DB196D-6640-49EA-A84F-2E87CA6F50C6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (767,'Road-650 Black, 62','BK-R50B-62',1,1,'Black',100,75,486.71,782.99,'62','CM ','LB ',20.00,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'C82A8309-63D3-4C0C-AD71-E91272397095','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (768,'Road-650 Black, 44','BK-R50B-44',1,1,'Black',100,75,486.71,782.99,'44','CM ','LB ',18.77,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'11D563AC-115C-4F0D-A1E5-E946EEE8B38B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (769,'Road-650 Black, 48','BK-R50B-48',1,1,'Black',100,75,486.71,782.99,'48','CM ','LB ',19.13,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'A7E2179E-137C-497E-A5E6-C9EA64935FB0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (770,'Road-650 Black, 52','BK-R50B-52',1,1,'Black',100,75,486.71,782.99,'52','CM ','LB ',19.42,4,'R ','L ','U ',2,30,'Jul  1 2001 12:00AM','Jun 30 2003 12:00AM',NULL,'136E2865-E0DA-4624-963A-31349279AB1A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (771,'Mountain-100 Silver, 38','BK-M82S-38',1,1,'Silver',100,75,1912.15,3399.99,'38','CM ','LB ',20.35,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'CA74B54E-FC30-4464-8B83-019BFD1B2DBB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (772,'Mountain-100 Silver, 42','BK-M82S-42',1,1,'Silver',100,75,1912.15,3399.99,'42','CM ','LB ',20.77,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'BBFFF5A5-4BDC-49A9-A5AD-7584ADFFE808','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (773,'Mountain-100 Silver, 44','BK-M82S-44',1,1,'Silver',100,75,1912.15,3399.99,'44','CM ','LB ',21.13,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'155FD77E-D6D6-43F0-8A5B-4A8305EB45CD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (774,'Mountain-100 Silver, 48','BK-M82S-48',1,1,'Silver',100,75,1912.15,3399.99,'48','CM ','LB ',21.42,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'BA5551DF-C9EE-4B43-B3CA-8C19D0F9384D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (775,'Mountain-100 Black, 38','BK-M82B-38',1,1,'Black',100,75,1898.09,3374.99,'38','CM ','LB ',20.35,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'DEA33347-FCD3-4346-AA0F-068CD6B3AD06','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (776,'Mountain-100 Black, 42','BK-M82B-42',1,1,'Black',100,75,1898.09,3374.99,'42','CM ','LB ',20.77,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'02935111-A546-4C6D-941F-BE12D42C158E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (777,'Mountain-100 Black, 44','BK-M82B-44',1,1,'Black',100,75,1898.09,3374.99,'44','CM ','LB ',21.13,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'7920BC3B-8FD4-4610-93D2-E693A66B6474','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (778,'Mountain-100 Black, 48','BK-M82B-48',1,1,'Black',100,75,1898.09,3374.99,'48','CM ','LB ',21.42,4,'M ','H ','U ',1,19,'Jul  1 2001 12:00AM','Jun 30 2002 12:00AM',NULL,'1B486300-7E64-4C5D-A9BA-A8368E20C5A0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (779,'Mountain-200 Silver, 38','BK-M68S-38',1,1,'Silver',100,75,1265.62,2319.99,'38','CM ','LB ',23.35,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'3A45D835-ABAE-4806-AC03-C53ABCD3B974','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (780,'Mountain-200 Silver, 42','BK-M68S-42',1,1,'Silver',100,75,1265.62,2319.99,'42','CM ','LB ',23.77,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'CE4849B4-56E6-4B50-808B-9BDE67CC4704','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (781,'Mountain-200 Silver, 46','BK-M68S-46',1,1,'Silver',100,75,1265.62,2319.99,'46','CM ','LB ',24.13,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'20799030-420C-496A-9922-09189C2B457E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (782,'Mountain-200 Black, 38','BK-M68B-38',1,1,'Black',100,75,1251.98,2294.99,'38','CM ','LB ',23.35,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'82CB8F9B-B8BB-4841-98D3-BCDB807C4DD8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (783,'Mountain-200 Black, 42','BK-M68B-42',1,1,'Black',100,75,1251.98,2294.99,'42','CM ','LB ',23.77,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'2B0AF5B9-7571-4621-B760-47DF599F9650','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (784,'Mountain-200 Black, 46','BK-M68B-46',1,1,'Black',100,75,1251.98,2294.99,'46','CM ','LB ',24.13,4,'M ','H ','U ',1,20,'Jul  1 2002 12:00AM',NULL,NULL,'33F42284-E216-4B98-BA48-B4EE18A01FA0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (785,'Mountain-300 Black, 38','BK-M47B-38',1,1,'Black',100,75,598.44,1079.99,'38','CM ','LB ',25.35,4,'M ','M ','U ',1,21,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'F06C2CBF-0901-4C08-80ED-FB4E87171B3B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (786,'Mountain-300 Black, 40','BK-M47B-40',1,1,'Black',100,75,598.44,1079.99,'40','CM ','LB ',25.77,4,'M ','M ','U ',1,21,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'580D4322-BE03-4C91-83D2-EE33EC6008AB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (787,'Mountain-300 Black, 44','BK-M47B-44',1,1,'Black',100,75,598.44,1079.99,'44','CM ','LB ',26.13,4,'M ','M ','U ',1,21,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'07C2A548-0452-47B4-9DCE-6EDB0A30C85E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (788,'Mountain-300 Black, 48','BK-M47B-48',1,1,'Black',100,75,598.44,1079.99,'48','CM ','LB ',26.42,4,'M ','M ','U ',1,21,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'16078DBE-388D-4C18-AA8F-0C8F48035468','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (789,'Road-250 Red, 44','BK-R89R-44',1,1,'Red',100,75,1518.79,2443.35,'44','CM ','LB ',14.77,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'0AA71AD6-AFAF-43C6-9745-35D815B50A5B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (790,'Road-250 Red, 48','BK-R89R-48',1,1,'Red',100,75,1518.79,2443.35,'48','CM ','LB ',15.13,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'115DDADE-70E3-43F9-80DC-638DAEA271C4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (791,'Road-250 Red, 52','BK-R89R-52',1,1,'Red',100,75,1518.79,2443.35,'52','CM ','LB ',15.42,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'C9FD1DF4-9512-420A-B379-067108033B75','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (792,'Road-250 Red, 58','BK-R89R-58',1,1,'Red',100,75,1554.95,2443.35,'58','CM ','LB ',15.79,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM',NULL,NULL,'DF629C11-8D8B-4774-9D52-ECB64DC95212','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (793,'Road-250 Black, 44','BK-R89B-44',1,1,'Black',100,75,1554.95,2443.35,'44','CM ','LB ',14.77,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM',NULL,NULL,'1FF419B5-52AF-4F7E-AEAE-4FEC5E99DE35','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (794,'Road-250 Black, 48','BK-R89B-48',1,1,'Black',100,75,1554.95,2443.35,'48','CM ','LB ',15.13,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM',NULL,NULL,'9D165DDF-8F5D-41C7-9BB8-13F41A3D1F62','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (795,'Road-250 Black, 52','BK-R89B-52',1,1,'Black',100,75,1554.95,2443.35,'52','CM ','LB ',15.42,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM',NULL,NULL,'74FE3957-CBC3-450A-AB92-849BD13530E2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (796,'Road-250 Black, 58','BK-R89B-58',1,1,'Black',100,75,1554.95,2443.35,'58','CM ','LB ',15.68,4,'R ','H ','U ',2,26,'Jul  1 2002 12:00AM',NULL,NULL,'1C530FE8-A169-4ADC-B3DC-B11A48245E63','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (797,'Road-550-W Yellow, 38','BK-R64Y-38',1,1,'Yellow',100,75,713.08,1120.49,'38','CM ','LB ',17.35,4,'R ','M ','W ',2,29,'Jul  1 2002 12:00AM',NULL,NULL,'AAD81532-A572-49A5-83C3-DFA9E3B4FEA6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (798,'Road-550-W Yellow, 40','BK-R64Y-40',1,1,'Yellow',100,75,713.08,1120.49,'40','CM ','LB ',17.77,4,'R ','M ','W ',2,29,'Jul  1 2002 12:00AM',NULL,NULL,'A35A1C35-C128-4697-951E-4199062E78F3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (799,'Road-550-W Yellow, 42','BK-R64Y-42',1,1,'Yellow',100,75,713.08,1120.49,'42','CM ','LB ',18.13,4,'R ','M ','W ',2,29,'Jul  1 2002 12:00AM',NULL,NULL,'A359AB09-16F2-4726-A60F-0DFDB1C9527E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (800,'Road-550-W Yellow, 44','BK-R64Y-44',1,1,'Yellow',100,75,713.08,1120.49,'44','CM ','LB ',18.42,4,'R ','M ','W ',2,29,'Jul  1 2002 12:00AM',NULL,NULL,'0A7028FB-FF06-4D38-AAA1-B64816278165','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (801,'Road-550-W Yellow, 48','BK-R64Y-48',1,1,'Yellow',100,75,713.08,1120.49,'48','CM ','LB ',18.68,4,'R ','M ','W ',2,29,'Jul  1 2002 12:00AM',NULL,NULL,'C90CC877-804C-4CE7-AFC3-4C8791A13DFB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (802,'LL Fork','FK-1639',1,1,NULL,500,375,65.81,148.22,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,10,104,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'FB8502BE-07EB-4134-AB06-C3A9959A52AE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (803,'ML Fork','FK-5136',1,1,NULL,500,375,77.92,175.49,NULL,NULL,NULL,NULL,1,NULL,'M ',NULL,10,105,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'F5FA4E2F-B976-48A4-BF79-85632F697D2E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (804,'HL Fork','FK-9939',1,1,NULL,500,375,101.89,229.49,NULL,NULL,NULL,NULL,1,NULL,'H ',NULL,10,106,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'553229B3-1AD9-4A71-A21C-2AF4332CFCE9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (805,'LL Headset','HS-0296',1,1,NULL,500,375,15.18,34.20,NULL,NULL,NULL,NULL,1,NULL,'L ',NULL,11,59,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'BB6BD7B3-A34D-4D64-822E-781FA6838E19','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (806,'ML Headset','HS-2451',1,1,NULL,500,375,45.42,102.29,NULL,NULL,NULL,NULL,1,NULL,'M ',NULL,11,60,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'23B5D52B-8C29-4059-B899-75C53B5EE2E6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (807,'HL Headset','HS-3479',1,1,NULL,500,375,55.38,124.73,NULL,NULL,NULL,NULL,1,NULL,'H ',NULL,11,61,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'12E4D5E8-79ED-4BCB-A532-6275D1A93417','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (808,'LL Mountain Handlebars','HB-M243',1,1,NULL,500,375,19.78,44.54,NULL,NULL,NULL,NULL,1,'M ','L ',NULL,4,52,'Jul  1 2002 12:00AM',NULL,NULL,'B59B7BF2-7AFC-4A74-B063-F942F1E0DA19','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (809,'ML Mountain Handlebars','HB-M763',1,1,NULL,500,375,27.49,61.92,NULL,NULL,NULL,NULL,1,'M ','M ',NULL,4,54,'Jul  1 2002 12:00AM',NULL,NULL,'AE6020DF-D9C9-4D34-9795-1F80E6BBF5A5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (810,'HL Mountain Handlebars','HB-M918',1,1,NULL,500,375,53.40,120.27,NULL,NULL,NULL,NULL,1,'M ','H ',NULL,4,55,'Jul  1 2002 12:00AM',NULL,NULL,'6AA0F921-0F09-4F99-8D3C-335946873553','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (811,'LL Road Handlebars','HB-R504',1,1,NULL,500,375,19.78,44.54,NULL,NULL,NULL,NULL,1,'R ','L ',NULL,4,56,'Jul  1 2002 12:00AM',NULL,NULL,'ACDAE407-B40E-435E-8E84-1BFC33013E81','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (812,'ML Road Handlebars','HB-R720',1,1,NULL,500,375,27.49,61.92,NULL,NULL,NULL,NULL,1,'R ','M ',NULL,4,57,'Jul  1 2002 12:00AM',NULL,NULL,'33FA1A03-38D6-405E-BE9B-EEA92F3D204F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (813,'HL Road Handlebars','HB-R956',1,1,NULL,500,375,53.40,120.27,NULL,NULL,NULL,NULL,1,'R ','H ',NULL,4,58,'Jul  1 2002 12:00AM',NULL,NULL,'5C5327B9-AD2E-4C33-8D74-EDF49E0C2DD8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (814,'ML Mountain Frame - Black, 38','FR-M63B-38',1,1,'Black',500,375,185.82,348.76,'38','CM ','LB ',2.73,2,'M ','M ','U ',12,15,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'0D879312-A7D3-441D-9D23-B6550BAB3814','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (815,'LL Mountain Front Wheel','FW-M423',1,1,'Black',500,375,26.97,60.75,NULL,NULL,NULL,NULL,1,'M ','L ',NULL,17,42,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'D7B1D161-182E-44F6-A9FF-9C1EBA76613B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (816,'ML Mountain Front Wheel','FW-M762',1,1,'Black',500,375,92.81,209.03,NULL,NULL,NULL,NULL,1,'M ','M ',NULL,17,45,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'5E3E5033-9A77-4DCA-8B7F-DFED78EFA08A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (817,'HL Mountain Front Wheel','FW-M928',1,1,'Black',500,375,133.30,300.22,NULL,NULL,NULL,NULL,1,'M ','H ',NULL,17,46,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'3C8FFFF6-A8DC-45A3-963B-A6284CED7596','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (818,'LL Road Front Wheel','FW-R623',1,1,'Black',500,375,37.99,85.57,NULL,NULL,'G  ',900.00,1,'R ','L ',NULL,17,49,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'9E66DE78-DECB-438A-B9A9-023C773C60A2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (819,'ML Road Front Wheel','FW-R762',1,1,'Black',500,375,110.28,248.39,NULL,NULL,'G  ',850.00,1,'R ','M ',NULL,17,50,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'6EA94FBF-B9AA-43FC-84E8-91D508DDE751','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (820,'HL Road Front Wheel','FW-R820',1,1,'Black',500,375,146.55,330.06,NULL,NULL,'G  ',650.00,1,'R ','H ',NULL,17,51,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'727A3CD5-8D40-4884-A7E4-DFD3FFDEB164','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (821,'Touring Front Wheel','FW-T905',1,1,'Black',500,375,96.80,218.01,NULL,NULL,NULL,NULL,1,'T ',NULL,NULL,17,44,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'8D1CDB07-4FA1-4AC1-840F-A16C3DCA5009','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (822,'ML Road Frame-W - Yellow, 38','FR-R72Y-38',1,1,'Yellow',500,375,360.94,594.83,'38','CM ','LB ',2.18,2,'R ','M ','W ',14,17,'Jul  1 2002 12:00AM',NULL,NULL,'22976FA7-0AD0-40F9-B4F9-BA10279EA1A3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (823,'LL Mountain Rear Wheel','RW-M423',1,1,'Black',500,375,38.96,87.75,NULL,NULL,NULL,NULL,1,'M ','L ',NULL,17,123,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'E6C39F58-995F-4786-A309-DF3812D8B30F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (824,'ML Mountain Rear Wheel','RW-M762',1,1,'Black',500,375,104.80,236.03,NULL,NULL,NULL,NULL,1,'M ','M ',NULL,17,124,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'B2F7CF9B-A7BF-49AB-9CCA-9F6E791CD693','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (825,'HL Mountain Rear Wheel','RW-M928',1,1,'Black',500,375,145.28,327.22,NULL,NULL,NULL,NULL,1,'M ','H ',NULL,17,125,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'35D02EDC-1120-41FB-B5DF-8655A93B3353','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (826,'LL Road Rear Wheel','RW-R623',1,1,'Black',500,375,49.98,112.57,NULL,NULL,'G  ',1050.00,1,'R ','L ',NULL,17,126,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'78D01117-8DCD-465F-9DC7-94A2CDC35582','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (827,'ML Road Rear Wheel','RW-R762',1,1,'Black',500,375,122.27,275.39,NULL,NULL,'G  ',1000.00,1,'R ','M ',NULL,17,77,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'CF739F9A-0AF0-4810-B229-C431A31D7779','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (828,'HL Road Rear Wheel','RW-R820',1,1,'Black',500,375,158.53,357.06,NULL,NULL,'G  ',890.00,1,'R ','H ',NULL,17,78,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'8F262A37-43AA-4AD5-AE1F-8BD6967D8E9B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (829,'Touring Rear Wheel','RW-T905',1,1,'Black',500,375,108.78,245.01,NULL,NULL,NULL,NULL,1,'T ',NULL,NULL,17,43,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'30D2254D-E26D-4586-B4C5-E8CCB8A059B8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (830,'ML Mountain Frame - Black, 40','FR-M63B-40',1,1,'Black',500,375,185.82,348.76,'40','CM ','LB ',2.77,1,'M ','M ','U ',12,14,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'AED1C9C4-C139-45D2-B38E-0A0A9F518665','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (831,'ML Mountain Frame - Black, 44','FR-M63B-44',1,1,'Black',500,375,185.82,348.76,'44','CM ','LB ',2.81,1,'M ','M ','U ',12,14,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'3F2135D4-EC5F-4E30-BDE8-5444518F0637','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (832,'ML Mountain Frame - Black, 48','FR-M63B-48',1,1,'Black',500,375,185.82,348.76,'48','CM ','LB ',2.85,1,'M ','M ','U ',12,14,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'C2009B69-F15A-47EC-B710-1809D299318A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (833,'ML Road Frame-W - Yellow, 40','FR-R72Y-40',1,1,'Yellow',500,375,360.94,594.83,'40','CM ','LB ',2.22,1,'R ','M ','W ',14,17,'Jul  1 2002 12:00AM',NULL,NULL,'22DF26F2-60BC-493E-A14A-5500633E9F7E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (834,'ML Road Frame-W - Yellow, 42','FR-R72Y-42',1,1,'Yellow',500,375,360.94,594.83,'42','CM ','LB ',2.26,1,'R ','M ','W ',14,17,'Jul  1 2002 12:00AM',NULL,NULL,'207B54DA-5404-415D-8578-9A45082E3BF1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (835,'ML Road Frame-W - Yellow, 44','FR-R72Y-44',1,1,'Yellow',500,375,360.94,594.83,'44','CM ','LB ',2.30,1,'R ','M ','W ',14,17,'Jul  1 2002 12:00AM',NULL,NULL,'A0FAD492-AC24-4FCF-8D2A-D21D06386AE1','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (836,'ML Road Frame-W - Yellow, 48','FR-R72Y-48',1,1,'Yellow',500,375,360.94,594.83,'48','CM ','LB ',2.34,1,'R ','M ','W ',14,17,'Jul  1 2002 12:00AM',NULL,NULL,'8487BFE0-2138-471E-9C6D-FDB3A67E7D86','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (837,'HL Road Frame - Black, 62','FR-R92B-62',1,1,'Black',500,375,868.63,1431.50,'62','CM ','LB ',2.30,1,'R ','H ','U ',14,6,'Jul  1 2002 12:00AM',NULL,NULL,'5DCE9C8C-FB94-46F8-B826-11658F6A3682','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (838,'HL Road Frame - Black, 44','FR-R92B-44',1,1,'Black',500,375,868.63,1431.50,'44','CM ','LB ',2.12,1,'R ','H ','U ',14,6,'Jul  1 2002 12:00AM',NULL,NULL,'E4902656-A4BC-4B08-9D47-4F3DA0FD76C3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (839,'HL Road Frame - Black, 48','FR-R92B-48',1,1,'Black',500,375,868.63,1431.50,'48','CM ','LB ',2.16,1,'R ','H ','U ',14,6,'Jul  1 2002 12:00AM',NULL,NULL,'557B603B-407B-41A4-AE34-4F7747866DBA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (840,'HL Road Frame - Black, 52','FR-R92B-52',1,1,'Black',500,375,868.63,1431.50,'52','CM ','LB ',2.20,1,'R ','H ','U ',14,6,'Jul  1 2002 12:00AM',NULL,NULL,'0ED082B3-FBBA-43AF-9149-8741B9FC78C8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (841,'Men''s Sports Shorts, S','SH-M897-S',0,1,'Black',4,3,24.75,59.99,'S',NULL,NULL,NULL,0,'S ',NULL,'M ',22,13,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'34B08C1F-99D1-43C4-8EF7-2CD754B6665D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (842,'Touring-Panniers, Large','PA-T100',0,1,'Grey',4,3,51.56,125.00,NULL,NULL,NULL,NULL,0,'T ',NULL,NULL,35,120,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'56334FFF-91D4-495E-BF98-933BC1010F23','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (843,'Cable Lock','LO-C100',0,1,NULL,4,3,10.31,25.00,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,34,115,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'56FFD7B9-1014-4640-B1BD-B2649589B4D7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (844,'Minipump','PU-0452',0,1,NULL,4,3,8.25,19.99,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,36,116,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'AAF7A076-9EE3-46BF-A69F-414D847E858B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (845,'Mountain Pump','PU-M044',0,1,NULL,4,3,10.31,24.99,NULL,NULL,NULL,NULL,0,'M ',NULL,NULL,36,117,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'57169F80-FAFB-4678-8F51-FE1F131D0C83','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (846,'Taillights - Battery-Powered','LT-T990',0,1,NULL,4,3,5.77,13.99,NULL,NULL,NULL,NULL,0,'R ',NULL,NULL,33,108,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'3C617B87-50A5-434C-A0D3-22314B7027EE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (847,'Headlights - Dual-Beam','LT-H902',0,1,NULL,4,3,14.43,34.99,NULL,NULL,NULL,NULL,0,'R ',NULL,NULL,33,109,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'417DB6CB-F38F-4B0D-87E7-E1EBF7456C3A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (848,'Headlights - Weatherproof','LT-H903',0,1,NULL,4,3,18.56,44.99,NULL,NULL,NULL,NULL,0,'R ',NULL,NULL,33,110,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'FC362C1A-4B9C-4D5F-A6D3-0775846C61F0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (849,'Men''s Sports Shorts, M','SH-M897-M',0,1,'Black',4,3,24.75,59.99,'M',NULL,NULL,NULL,0,'S ',NULL,'M ',22,13,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'DB37B435-74B9-43D3-B363-ABBEAD107BC4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (850,'Men''s Sports Shorts, L','SH-M897-L',0,1,'Black',4,3,24.75,59.99,'L',NULL,NULL,NULL,0,'S ',NULL,'M ',22,13,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'714184C5-669B-4CF1-A802-30E7B1EA7722','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (851,'Men''s Sports Shorts, XL','SH-M897-X',0,1,'Black',4,3,24.75,59.99,'XL',NULL,NULL,NULL,0,'S ',NULL,'M ',22,13,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'BD3FFE40-FE2E-44CB-A4E0-81786C3A751F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (852,'Women''s Tights, S','TG-W091-S',0,1,'Black',4,3,30.93,74.99,'S',NULL,NULL,NULL,0,'S ',NULL,'W ',24,38,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'7DE86C98-4F5B-4155-8572-C977F14EBAEB','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (853,'Women''s Tights, M','TG-W091-M',0,1,'Black',4,3,30.93,74.99,'M',NULL,NULL,NULL,0,'S ',NULL,'W ',24,38,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'4D8E186C-B8C9-4C64-B411-4995DD87E316','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (854,'Women''s Tights, L','TG-W091-L',0,1,'Black',4,3,30.93,74.99,'L',NULL,NULL,NULL,0,'S ',NULL,'W ',24,38,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'E378C2F3-54F6-4EA9-B049-E8BB32B5BDFD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (855,'Men''s Bib-Shorts, S','SB-M891-S',0,1,'Multi',4,3,37.12,89.99,'S',NULL,NULL,NULL,0,'S ',NULL,'M ',18,12,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'9F60AF1E-4C11-4E90-BAEA-48E834E8B4C2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (856,'Men''s Bib-Shorts, M','SB-M891-M',0,1,'Multi',4,3,37.12,89.99,'M',NULL,NULL,NULL,0,'S ',NULL,'M ',18,12,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'E0CBEC04-F4FC-450F-9780-F8EA7691FEBD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (857,'Men''s Bib-Shorts, L','SB-M891-L',0,1,'Multi',4,3,37.12,89.99,'L',NULL,NULL,NULL,0,'S ',NULL,'M ',18,12,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'E1DF75A4-9986-489E-A5DE-AD3DA824EB5E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (858,'Half-Finger Gloves, S','GL-H102-S',0,1,'Black',4,3,9.16,24.49,'S',NULL,NULL,NULL,0,'S ',NULL,'U ',20,4,'Jul  1 2002 12:00AM',NULL,NULL,'9E1DB5C3-539D-4061-9433-D762DC195CD8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (859,'Half-Finger Gloves, M','GL-H102-M',0,1,'Black',4,3,9.16,24.49,'M',NULL,NULL,NULL,0,'S ',NULL,'U ',20,4,'Jul  1 2002 12:00AM',NULL,NULL,'9D458FD5-392D-4AB1-AFEF-6A5548E48858','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (860,'Half-Finger Gloves, L','GL-H102-L',0,1,'Black',4,3,9.16,24.49,'L',NULL,NULL,NULL,0,'S ',NULL,'U ',20,4,'Jul  1 2002 12:00AM',NULL,NULL,'FA710215-925F-4959-81DF-538E72A6A255','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (861,'Full-Finger Gloves, S','GL-F110-S',0,1,'Black',4,3,15.67,37.99,'S',NULL,NULL,NULL,0,'M ',NULL,'U ',20,3,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'76FAC097-1FB3-456B-8FB9-2C7A613771B4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (862,'Full-Finger Gloves, M','GL-F110-M',0,1,'Black',4,3,15.67,37.99,'M',NULL,NULL,NULL,0,'M ',NULL,'U ',20,3,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'1084221E-1890-443E-9D87-AFCAD6358355','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (863,'Full-Finger Gloves, L','GL-F110-L',0,1,'Black',4,3,15.67,37.99,'L',NULL,NULL,NULL,0,'M ',NULL,'U ',20,3,'Jul  1 2002 12:00AM','Jun 30 2003 12:00AM',NULL,'6116F9D4-8A1D-4022-A642-9C445C197203','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (864,'Classic Vest, S','VE-C304-S',0,1,'Blue',4,3,23.75,63.50,'S',NULL,NULL,NULL,0,'S ',NULL,'U ',25,1,'Jul  1 2003 12:00AM',NULL,NULL,'EB423EF3-409D-46FE-B35B-D69970820314','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (865,'Classic Vest, M','VE-C304-M',0,1,'Blue',4,3,23.75,63.50,'M',NULL,NULL,NULL,0,'S ',NULL,'U ',25,1,'Jul  1 2003 12:00AM',NULL,NULL,'2E52F96E-64A1-4069-911C-E3FD6E094A1E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (866,'Classic Vest, L','VE-C304-L',0,1,'Blue',4,3,23.75,63.50,'L',NULL,NULL,NULL,0,'S ',NULL,'U ',25,1,'Jul  1 2003 12:00AM',NULL,NULL,'3211F5A8-B6C4-48BD-9AA4-D69CB40D97DD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (867,'Women''s Mountain Shorts, S','SH-W890-S',0,1,'Black',4,3,26.18,69.99,'S',NULL,NULL,NULL,0,'M ',NULL,'W ',22,37,'Jul  1 2003 12:00AM',NULL,NULL,'22616FD2-B99F-4F7D-ACF6-33DFF66D42D2','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (868,'Women''s Mountain Shorts, M','SH-W890-M',0,1,'Black',4,3,26.18,69.99,'M',NULL,NULL,NULL,0,'M ',NULL,'W ',22,37,'Jul  1 2003 12:00AM',NULL,NULL,'968E3610-E583-42E8-8AB6-484A799B1774','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (869,'Women''s Mountain Shorts, L','SH-W890-L',0,1,'Black',4,3,26.18,69.99,'L',NULL,NULL,NULL,0,'M ',NULL,'W ',22,37,'Jul  1 2003 12:00AM',NULL,NULL,'1A66B244-5CA0-4153-B539-AE048D14FAEC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (870,'Water Bottle - 30 oz.','WB-H098',0,1,NULL,4,3,1.87,4.99,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,28,111,'Jul  1 2003 12:00AM',NULL,NULL,'834E8D1A-69A7-4C42-8B68-FA08D9EC9E5B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (871,'Mountain Bottle Cage','BC-M005',0,1,NULL,4,3,3.74,9.99,NULL,NULL,NULL,NULL,0,'M ',NULL,NULL,28,112,'Jul  1 2003 12:00AM',NULL,NULL,'684491DE-63F8-4632-90E3-36773C4E63BD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (872,'Road Bottle Cage','BC-R205',0,1,NULL,4,3,3.36,8.99,NULL,NULL,NULL,NULL,0,'R ',NULL,NULL,28,113,'Jul  1 2003 12:00AM',NULL,NULL,'601B1FE8-D4D0-4CFB-9379-29481CC05291','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (873,'Patch Kit/8 Patches','PK-7098',0,1,NULL,4,3,0.86,2.29,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,37,114,'Jul  1 2003 12:00AM',NULL,NULL,'36E638E4-68DF-411B-930A-DAAD57221AA6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (874,'Racing Socks, M','SO-R809-M',0,1,'White',4,3,3.36,8.99,'M',NULL,NULL,NULL,0,'R ',NULL,'U ',23,24,'Jul  1 2003 12:00AM',NULL,NULL,'B9C7EB0A-1DD1-4A1D-B4C3-1DAD83A8EA7E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (875,'Racing Socks, L','SO-R809-L',0,1,'White',4,3,3.36,8.99,'L',NULL,NULL,NULL,0,'R ',NULL,'U ',23,24,'Jul  1 2003 12:00AM',NULL,NULL,'C0A16305-74B7-4FAE-B5C9-3E8BD0E44762','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (876,'Hitch Rack - 4-Bike','RA-H123',0,1,NULL,4,3,44.88,120.00,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,26,118,'Jul  1 2003 12:00AM',NULL,NULL,'7A0C4BBD-9679-4F59-9EBC-9DAF3439A38A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (877,'Bike Wash - Dissolver','CL-9009',0,1,NULL,4,3,2.97,7.95,NULL,NULL,NULL,NULL,0,'S ',NULL,NULL,29,119,'Jul  1 2003 12:00AM',NULL,NULL,'3C40B5AD-E328-4715-88A7-EC3220F02ACF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (878,'Fender Set - Mountain','FE-6654',0,1,NULL,4,3,8.22,21.98,NULL,NULL,NULL,NULL,0,'M ',NULL,NULL,30,121,'Jul  1 2003 12:00AM',NULL,NULL,'E6E76C7F-C145-4CAD-A9E8-B1E4E845A2C0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (879,'All-Purpose Bike Stand','ST-1401',0,1,NULL,4,3,59.47,159.00,NULL,NULL,NULL,NULL,0,'M ',NULL,NULL,27,122,'Jul  1 2003 12:00AM',NULL,NULL,'C7BB564B-A637-40F5-B21B-CBF7E4F713BE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (880,'Hydration Pack - 70 oz.','HY-1023-70',0,1,'Silver',4,3,20.57,54.99,'70',NULL,NULL,NULL,0,'S ',NULL,NULL,32,107,'Jul  1 2003 12:00AM',NULL,NULL,'A99D90C0-05E2-4E44-AD90-C55C9F0784DE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (881,'Short-Sleeve Classic Jersey, S','SJ-0194-S',0,1,'Yellow',4,3,41.57,53.99,'S',NULL,NULL,NULL,0,'S ',NULL,'U ',21,32,'Jul  1 2003 12:00AM',NULL,NULL,'05B2E20F-2399-4CB3-9B49-B28D6649C104','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (882,'Short-Sleeve Classic Jersey, M','SJ-0194-M',0,1,'Yellow',4,3,41.57,53.99,'M',NULL,NULL,NULL,0,'S ',NULL,'U ',21,32,'Jul  1 2003 12:00AM',NULL,NULL,'BBBF003B-367D-4D71-AF71-10F50B6234A0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (883,'Short-Sleeve Classic Jersey, L','SJ-0194-L',0,1,'Yellow',4,3,41.57,53.99,'L',NULL,NULL,NULL,0,'S ',NULL,'U ',21,32,'Jul  1 2003 12:00AM',NULL,NULL,'2D9F59B8-9F24-46EB-98AD-553E48BB9DB9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (884,'Short-Sleeve Classic Jersey, XL','SJ-0194-X',0,1,'Yellow',4,3,41.57,53.99,'XL',NULL,NULL,NULL,0,'S ',NULL,'U ',21,32,'Jul  1 2003 12:00AM',NULL,NULL,'906D42F6-C21F-4D20-B528-02FFDB55FD1E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (885,'HL Touring Frame - Yellow, 60','FR-T98Y-60',1,1,'Yellow',500,375,601.74,1003.91,'60','CM ','LB ',3.08,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'C49679BD-96A9-4176-A7ED-5BC6D6444647','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (886,'LL Touring Frame - Yellow, 62','FR-T67Y-62',1,1,'Yellow',500,375,199.85,333.42,'62','CM ','LB ',3.20,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'8D4D52A6-8ABC-4C05-BE4D-C067FAF1A64E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (887,'HL Touring Frame - Yellow, 46','FR-T98Y-46',1,1,'Yellow',500,375,601.74,1003.91,'46','CM ','LB ',2.96,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'137675A7-34CD-4B7A-ABE1-4E0EEB79B65D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (888,'HL Touring Frame - Yellow, 50','FR-T98Y-50',1,1,'Yellow',500,375,601.74,1003.91,'50','CM ','LB ',3.00,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'105EC6E5-30C5-4FE3-A08B-CB324C85323D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (889,'HL Touring Frame - Yellow, 54','FR-T98Y-54',1,1,'Yellow',500,375,601.74,1003.91,'54','CM ','LB ',3.04,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'12B1F317-C39B-48D0-B1A7-8018C60AEA53','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (890,'HL Touring Frame - Blue, 46','FR-T98U-46',1,1,'Blue',500,375,601.74,1003.91,'46','CM ','LB ',2.96,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'8BBD3437-A58B-41A0-9503-FC14B23E7678','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (891,'HL Touring Frame - Blue, 50','FR-T98U-50',1,1,'Blue',500,375,601.74,1003.91,'50','CM ','LB ',3.00,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'C4244F0C-ABCE-451B-A895-83C0E6D1F448','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (892,'HL Touring Frame - Blue, 54','FR-T98U-54',1,1,'Blue',500,375,601.74,1003.91,'54','CM ','LB ',3.04,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'E9AAE947-6BC3-4909-8937-3E1CDCEC8A8F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (893,'HL Touring Frame - Blue, 60','FR-T98U-60',1,1,'Blue',500,375,601.74,1003.91,'60','CM ','LB ',3.08,1,'T ','H ','U ',16,7,'Jul  1 2003 12:00AM',NULL,NULL,'B01951A4-A581-4D10-9DC2-515DA180F1B8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (894,'Rear Derailleur','RD-2308',1,1,'Silver',500,375,53.93,121.46,NULL,NULL,'G  ',215.00,1,NULL,NULL,NULL,9,127,'Jul  1 2003 12:00AM',NULL,NULL,'5EBFCF02-4E3E-443A-AD60-5AEEF28DAC76','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (895,'LL Touring Frame - Blue, 50','FR-T67U-50',1,1,'Blue',500,375,199.85,333.42,'50','CM ','LB ',3.10,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'B78ECCCA-FA88-4071-9110-410585127E46','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (896,'LL Touring Frame - Blue, 54','FR-T67U-54',1,1,'Blue',500,375,199.85,333.42,'54','CM ','LB ',3.14,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'0FF799C9-DD11-4B81-AAF7-65410017405B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (897,'LL Touring Frame - Blue, 58','FR-T67U-58',1,1,'Blue',500,375,199.85,333.42,'58','CM ','LB ',3.16,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'CCD4FA47-7194-4BD0-909B-1FA4BD7916A7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (898,'LL Touring Frame - Blue, 62','FR-T67U-62',1,1,'Blue',500,375,199.85,333.42,'62','CM ','LB ',3.20,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'08A211A5-DCD2-42D0-9276-64D92D4890A6','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (899,'LL Touring Frame - Yellow, 44','FR-T67Y-44',1,1,'Yellow',500,375,199.85,333.42,'44','CM ','LB ',3.02,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'109CB7BC-6EC6-4A36-85C8-55B843B2AB12','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (900,'LL Touring Frame - Yellow, 50','FR-T67Y-50',1,1,'Yellow',500,375,199.85,333.42,'50','CM ','LB ',3.10,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'285FD682-C647-49D1-B8F3-368A43C9CDA0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (901,'LL Touring Frame - Yellow, 54','FR-T67Y-54',1,1,'Yellow',500,375,199.85,333.42,'54','CM ','LB ',3.14,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'2536E3B2-D4DA-49E6-965A-F612C2C8914F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (902,'LL Touring Frame - Yellow, 58','FR-T67Y-58',1,1,'Yellow',500,375,199.85,333.42,'58','CM ','LB ',3.16,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'5D17FF1C-F50E-438F-A4E9-7C400FB762E7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (903,'LL Touring Frame - Blue, 44','FR-T67U-44',1,1,'Blue',500,375,199.85,333.42,'44','CM ','LB ',3.02,1,'T ','L ','U ',16,10,'Jul  1 2003 12:00AM',NULL,NULL,'E9C17BE7-F4DC-465E-AB73-C0198F37BFDD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (904,'ML Mountain Frame-W - Silver, 40','FR-M63S-40',1,1,'Silver',500,375,199.38,364.09,'40','CM ','LB ',2.77,1,'M ','M ','W ',12,15,'Jul  1 2003 12:00AM',NULL,NULL,'A7DDE43E-F7D5-4075-A0C1-C866AD7AA154','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (905,'ML Mountain Frame-W - Silver, 42','FR-M63S-42',1,1,'Silver',500,375,199.38,364.09,'42','CM ','LB ',2.81,1,'M ','M ','W ',12,15,'Jul  1 2003 12:00AM',NULL,NULL,'D4A2FCAD-1E63-4EBD-863C-5A7C48D5B8D9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (906,'ML Mountain Frame-W - Silver, 46','FR-M63S-46',1,1,'Silver',500,375,199.38,364.09,'46','CM ','LB ',2.85,1,'M ','M ','W ',12,15,'Jul  1 2003 12:00AM',NULL,NULL,'82025C63-7B28-412D-92C1-408E0E6AE646','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (907,'Rear Brakes','RB-9231',0,1,'Silver',500,375,47.29,106.50,NULL,NULL,'G  ',317.00,1,NULL,NULL,NULL,6,128,'Jul  1 2003 12:00AM',NULL,NULL,'5946F163-93F0-4141-B17E-55D9778CC274','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (908,'LL Mountain Seat/Saddle','SE-M236',0,1,NULL,500,375,12.04,27.12,NULL,NULL,NULL,NULL,1,'M ','L ',NULL,15,79,'Jul  1 2003 12:00AM',NULL,NULL,'4DAB53C5-31E7-47D6-A5A0-940F8D4DAD22','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (909,'ML Mountain Seat/Saddle','SE-M798',0,1,NULL,500,375,17.38,39.14,NULL,NULL,NULL,NULL,1,'M ','M ',NULL,15,80,'Jul  1 2003 12:00AM',NULL,NULL,'30222244-0FD8-4D28-8448-F2E658BF52BD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (910,'HL Mountain Seat/Saddle','SE-M940',0,1,NULL,500,375,23.37,52.64,NULL,NULL,NULL,NULL,1,'M ','H ',NULL,15,81,'Jul  1 2003 12:00AM',NULL,NULL,'A96A5024-87DE-488A-BF81-BC0C81F6CD18','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (911,'LL Road Seat/Saddle','SE-R581',0,1,NULL,500,375,12.04,27.12,NULL,NULL,NULL,NULL,1,'R ','L ',NULL,15,82,'Jul  1 2003 12:00AM',NULL,NULL,'31B9BC62-792B-4E7A-A24D-411DC76E0271','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (912,'ML Road Seat/Saddle','SE-R908',0,1,NULL,500,375,17.38,39.14,NULL,NULL,NULL,NULL,1,'T ','M ',NULL,15,83,'Jul  1 2003 12:00AM',NULL,NULL,'49845AFE-A8CC-4354-A5D4-09D35BF7FB9E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (913,'HL Road Seat/Saddle','SE-R995',0,1,NULL,500,375,23.37,52.64,NULL,NULL,NULL,NULL,1,'R ','H ',NULL,15,84,'Jul  1 2003 12:00AM',NULL,NULL,'2BEFE629-4B2A-41A1-A009-DF13EAD69105','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (914,'LL Touring Seat/Saddle','SE-T312',0,1,NULL,500,375,12.04,27.12,NULL,NULL,NULL,NULL,1,'T ','L ',NULL,15,66,'Jul  1 2003 12:00AM',NULL,NULL,'7874A1D6-7A5B-412F-A2EB-C2F457B9603D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (915,'ML Touring Seat/Saddle','SE-T762',0,1,NULL,500,375,17.38,39.14,NULL,NULL,NULL,NULL,1,'T ','M ',NULL,15,65,'Jul  1 2003 12:00AM',NULL,NULL,'072ACB72-7796-4BD0-9BBB-6EFC29AC336C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (916,'HL Touring Seat/Saddle','SE-T924',0,1,NULL,500,375,23.37,52.64,NULL,NULL,NULL,NULL,1,'T ','H ',NULL,15,67,'Jul  1 2003 12:00AM',NULL,NULL,'0E158724-934D-4A64-991F-94FEC00BDEA8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (917,'LL Mountain Frame - Silver, 42','FR-M21S-42',1,1,'Silver',500,375,144.59,264.05,'42','CM ','LB ',2.92,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'37BD4D2B-346B-4C6B-8F3F-85C084282529','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (918,'LL Mountain Frame - Silver, 44','FR-M21S-44',1,1,'Silver',500,375,144.59,264.05,'44','CM ','LB ',2.96,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'393A4D00-7428-41F0-A48A-AF26B00E9A9C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (919,'LL Mountain Frame - Silver, 48','FR-M21S-48',1,1,'Silver',500,375,144.59,264.05,'48','CM ','LB ',3.00,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'8DFEF6F2-91A8-4884-8949-B2551218B37A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (920,'LL Mountain Frame - Silver, 52','FR-M21S-52',1,1,'Silver',500,375,144.59,264.05,'52','CM ','LB ',3.04,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'F230BAAC-5951-4EB1-B1E8-94C2CA2B37FA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (921,'Mountain Tire Tube','TT-M928',0,1,NULL,500,375,1.87,4.99,NULL,NULL,NULL,NULL,0,'M ',NULL,NULL,37,92,'Jul  1 2003 12:00AM',NULL,NULL,'01A8C3FC-ED52-458E-A634-D5B6E2ACCFED','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (922,'Road Tire Tube','TT-R982',0,1,NULL,500,375,1.49,3.99,NULL,NULL,NULL,NULL,0,'R ',NULL,NULL,37,93,'Jul  1 2003 12:00AM',NULL,NULL,'EA442BD7-F69B-42D9-AA71-95E10B648F52','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (923,'Touring Tire Tube','TT-T092',0,1,NULL,500,375,1.87,4.99,NULL,NULL,NULL,NULL,0,'T ',NULL,NULL,37,94,'Jul  1 2003 12:00AM',NULL,NULL,'179FEC38-CAB5-4A47-BCFF-31CFC9E43A3C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (924,'LL Mountain Frame - Black, 42','FR-M21B-42',1,1,'Black',500,375,136.79,249.79,'42','CM ','LB ',2.92,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'FAABD7FB-CB35-4BAD-8857-EC71468686AD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (925,'LL Mountain Frame - Black, 44','FR-M21B-44',1,1,'Black',500,375,136.79,249.79,'44','CM ','LB ',2.96,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'47AB0300-7B55-4D35-A786-80190976B9B5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (926,'LL Mountain Frame - Black, 48','FR-M21B-48',1,1,'Black',500,375,136.79,249.79,'48','CM ','LB ',3.00,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'408435AA-15C0-41E5-981F-32A8226AF15F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (927,'LL Mountain Frame - Black, 52','FR-M21B-52',1,1,'Black',500,375,136.79,249.79,'52','CM ','LB ',3.04,1,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'4800F4E6-99EA-4AFD-A392-2CB05265D0D4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (928,'LL Mountain Tire','TI-M267',0,1,NULL,500,375,9.35,24.99,NULL,NULL,NULL,NULL,0,'M ','L ',NULL,37,85,'Jul  1 2003 12:00AM',NULL,NULL,'76060A93-949C-48EA-9B31-A593D6C14983','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (929,'ML Mountain Tire','TI-M602',0,1,NULL,500,375,11.22,29.99,NULL,NULL,NULL,NULL,0,'M ','M ',NULL,37,86,'Jul  1 2003 12:00AM',NULL,NULL,'DAFF9E11-6254-432D-8C4F-F06E52687184','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (930,'HL Mountain Tire','TI-M823',0,1,NULL,500,375,13.09,35.00,NULL,NULL,NULL,NULL,0,'M ','H ',NULL,37,87,'Jul  1 2003 12:00AM',NULL,NULL,'DDAD25F5-0445-4B5C-8466-6446930AD8B8','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (931,'LL Road Tire','TI-R092',0,1,NULL,500,375,8.04,21.49,NULL,NULL,NULL,NULL,0,'R ','L ',NULL,37,88,'Jul  1 2003 12:00AM',NULL,NULL,'15B569A6-D172-42C2-A420-62AB5946CC80','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (932,'ML Road Tire','TI-R628',0,1,NULL,500,375,9.35,24.99,NULL,NULL,NULL,NULL,0,'R ','M ',NULL,37,89,'Jul  1 2003 12:00AM',NULL,NULL,'D1016CC5-C12B-4F05-915C-70FA062E4A64','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (933,'HL Road Tire','TI-R982',0,1,NULL,500,375,12.19,32.60,NULL,NULL,NULL,NULL,0,'R ','H ',NULL,37,90,'Jul  1 2003 12:00AM',NULL,NULL,'C86DE56A-5048-4B89-B7C7-56BC75C9BCEE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (934,'Touring Tire','TI-T723',0,1,NULL,500,375,10.84,28.99,NULL,NULL,NULL,NULL,0,'T ',NULL,NULL,37,91,'Jul  1 2003 12:00AM',NULL,NULL,'9D5CA300-5302-41E1-BCA5-8CE5B93F26A5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (935,'LL Mountain Pedal','PD-M282',0,1,'Silver/Black',500,375,17.98,40.49,NULL,NULL,'G  ',218.00,1,'M ','L ',NULL,13,62,'Jul  1 2003 12:00AM',NULL,NULL,'9FDD0C65-B2B0-4C6C-8704-3A9747BE5174','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (936,'ML Mountain Pedal','PD-M340',0,1,'Silver/Black',500,375,27.57,62.09,NULL,NULL,'G  ',215.00,1,'M ','M ',NULL,13,63,'Jul  1 2003 12:00AM',NULL,NULL,'274C86DC-439E-4469-9DE8-7E9BD6455D0D','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (937,'HL Mountain Pedal','PD-M562',0,1,'Silver/Black',500,375,35.96,80.99,NULL,NULL,'G  ',185.00,1,'M ','H ',NULL,13,64,'Jul  1 2003 12:00AM',NULL,NULL,'A05464E8-6B4D-42B3-A4D6-8683136F4B66','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (938,'LL Road Pedal','PD-R347',0,1,'Silver/Black',500,375,17.98,40.49,NULL,NULL,'G  ',189.00,1,'R ','L ',NULL,13,68,'Jul  1 2003 12:00AM',NULL,NULL,'2C7DD8C3-4C55-475F-BA58-F4BACA520D72','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (939,'ML Road Pedal','PD-R563',0,1,'Silver/Black',500,375,27.57,62.09,NULL,NULL,'G  ',168.00,1,'R ','M ',NULL,13,69,'Jul  1 2003 12:00AM',NULL,NULL,'216AD46F-BC3F-4862-B0E9-2E261E5A6059','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (940,'HL Road Pedal','PD-R853',0,1,'Silver/Black',500,375,35.96,80.99,NULL,NULL,'G  ',149.00,1,'R ','H ',NULL,13,70,'Jul  1 2003 12:00AM',NULL,NULL,'44E96967-AB99-41ED-8B41-5BC70A5CA1A9','Mar 11 2004 10:03AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (941,'Touring Pedal','PD-T852',0,1,'Silver/Black',500,375,35.96,80.99,NULL,NULL,NULL,NULL,1,'T ',NULL,NULL,13,53,'Jul  1 2003 12:00AM',NULL,NULL,'6967C816-3EBB-45FA-8547-CEF00E08573E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (942,'ML Mountain Frame-W - Silver, 38','FR-M63S-38',1,1,'Silver',500,375,199.38,364.09,'38','CM ','LB ',2.73,2,'M ','M ','W ',12,15,'Jul  1 2003 12:00AM',NULL,NULL,'BA3646B0-1487-426E-AB4E-57D42E6F9233','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (943,'LL Mountain Frame - Black, 40','FR-M21B-40',1,1,'Black',500,375,136.79,249.79,'40','CM ','LB ',2.88,2,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'3050E4DF-2BBA-4C2B-BDCC-B4C89972DB1C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (944,'LL Mountain Frame - Silver, 40','FR-M21S-40',1,1,'Silver',500,375,144.59,264.05,'40','CM ','LB ',2.88,2,'M ','L ','U ',12,8,'Jul  1 2003 12:00AM',NULL,NULL,'756F862E-40CC-4DFC-B189-716D0DDA5FF9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (945,'Front Derailleur','FD-2342',1,1,'Silver',500,375,40.62,91.49,NULL,NULL,'G  ',88.00,1,NULL,NULL,NULL,9,103,'Jul  1 2003 12:00AM',NULL,NULL,'448E9E7B-9548-4A4C-ABB3-853686AA7517','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (946,'LL Touring Handlebars','HB-T721',1,1,NULL,500,375,20.46,46.09,NULL,NULL,NULL,NULL,1,'T ','L ',NULL,4,47,'Jul  1 2003 12:00AM',NULL,NULL,'A2F1352E-45D0-42C4-AEF3-60033073BB66','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (947,'HL Touring Handlebars','HB-T928',1,1,NULL,500,375,40.66,91.57,NULL,NULL,NULL,NULL,1,'T ','H ',NULL,4,48,'Jul  1 2003 12:00AM',NULL,NULL,'CB524E92-4FA8-4F6C-9993-60796856C654','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (948,'Front Brakes','FB-9873',0,1,'Silver',500,375,47.29,106.50,NULL,NULL,'G  ',317.00,1,NULL,NULL,NULL,6,102,'Jul  1 2003 12:00AM',NULL,NULL,'C1813164-1B4B-42D1-9007-4E5F9AEE0E19','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (949,'LL Crankset','CS-4759',1,1,'Black',500,375,77.92,175.49,NULL,NULL,'G  ',600.00,1,NULL,'L ',NULL,8,99,'Jul  1 2003 12:00AM',NULL,NULL,'41D47371-4374-46D3-8D61-B07616EC54F0','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (950,'ML Crankset','CS-6583',1,1,'Black',500,375,113.88,256.49,NULL,NULL,'G  ',635.00,1,NULL,'M ',NULL,8,100,'Jul  1 2003 12:00AM',NULL,NULL,'D3A7A02C-A3D5-4A04-9454-0C4E43772B78','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (951,'HL Crankset','CS-9183',1,1,'Black',500,375,179.82,404.99,NULL,NULL,'G  ',575.00,1,NULL,'H ',NULL,8,101,'Jul  1 2003 12:00AM',NULL,NULL,'2C4A8956-7B72-48FE-B028-699E117B1DAA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (952,'Chain','CH-0234',0,1,'Silver',500,375,8.99,20.24,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,7,98,'Jul  1 2003 12:00AM',NULL,NULL,'5D27E2A5-27EC-4CCB-BA2C-FC980FFE6708','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (953,'Touring-2000 Blue, 60','BK-T44U-60',1,1,'Blue',100,75,755.15,1214.85,'60','CM ','LB ',27.90,4,'T ','M ','U ',3,35,'Jul  1 2003 12:00AM',NULL,NULL,'F1BB3957-8D27-47F3-91EC-C71822D11436','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (954,'Touring-1000 Yellow, 46','BK-T79Y-46',1,1,'Yellow',100,75,1481.94,2384.07,'46','CM ','LB ',25.13,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'83B77413-8C8A-4AF1-93E4-136EDB7FF15F','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (955,'Touring-1000 Yellow, 50','BK-T79Y-50',1,1,'Yellow',100,75,1481.94,2384.07,'50','CM ','LB ',25.42,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'5EC991AD-8761-4A61-A318-312DF3A78604','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (956,'Touring-1000 Yellow, 54','BK-T79Y-54',1,1,'Yellow',100,75,1481.94,2384.07,'54','CM ','LB ',25.68,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'1220B0F0-064D-46B7-8507-1FA758B77B9C','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (957,'Touring-1000 Yellow, 60','BK-T79Y-60',1,1,'Yellow',100,75,1481.94,2384.07,'60','CM ','LB ',25.90,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'BCD1A5A9-6140-4DC9-9620-689DC7E4C155','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (958,'Touring-3000 Blue, 54','BK-T18U-54',1,1,'Blue',100,75,461.44,742.35,'54','CM ','LB ',29.68,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'A3EE6897-52FE-42E4-92EC-7A91E7BB905A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (959,'Touring-3000 Blue, 58','BK-T18U-58',1,1,'Blue',100,75,461.44,742.35,'58','CM ','LB ',29.90,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'23D89CEE-9F44-4F3E-B289-63DE6BA2B737','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (960,'Touring-3000 Blue, 62','BK-T18U-62',1,1,'Blue',100,75,461.44,742.35,'62','CM ','LB ',30.00,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'060192C9-BCD9-4260-B729-D6BCFADFB08E','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (961,'Touring-3000 Yellow, 44','BK-T18Y-44',1,1,'Yellow',100,75,461.44,742.35,'44','CM ','LB ',28.77,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'5646C15A-68AD-4234-B328-254706CBCCC5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (962,'Touring-3000 Yellow, 50','BK-T18Y-50',1,1,'Yellow',100,75,461.44,742.35,'50','CM ','LB ',29.13,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'DF85E805-AF87-4FAB-A668-C80F2A5B8A69','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (963,'Touring-3000 Yellow, 54','BK-T18Y-54',1,1,'Yellow',100,75,461.44,742.35,'54','CM ','LB ',29.42,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'192BECD1-F465-4194-88A2-EE57FED3A3C5','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (964,'Touring-3000 Yellow, 58','BK-T18Y-58',1,1,'Yellow',100,75,461.44,742.35,'58','CM ','LB ',29.79,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'BED79F64-A53D-44A3-ACE8-2BAA425A5A54','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (965,'Touring-3000 Yellow, 62','BK-T18Y-62',1,1,'Yellow',100,75,461.44,742.35,'62','CM ','LB ',30.00,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'D28B3872-5173-40A4-B12F-655524386CC7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (966,'Touring-1000 Blue, 46','BK-T79U-46',1,1,'Blue',100,75,1481.94,2384.07,'46','CM ','LB ',25.13,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'86990D54-6EFB-4C53-9974-6C3B0297E222','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (967,'Touring-1000 Blue, 50','BK-T79U-50',1,1,'Blue',100,75,1481.94,2384.07,'50','CM ','LB ',25.42,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'68C0A818-2985-46EB-8255-0FB70919FA24','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (968,'Touring-1000 Blue, 54','BK-T79U-54',1,1,'Blue',100,75,1481.94,2384.07,'54','CM ','LB ',25.68,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'12280A8C-7578-4367-BA71-214BCC1E4792','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (969,'Touring-1000 Blue, 60','BK-T79U-60',1,1,'Blue',100,75,1481.94,2384.07,'60','CM ','LB ',25.90,4,'T ','H ','U ',3,34,'Jul  1 2003 12:00AM',NULL,NULL,'DD70CF36-449A-43FD-839D-A84EE14C849A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (970,'Touring-2000 Blue, 46','BK-T44U-46',1,1,'Blue',100,75,755.15,1214.85,'46','CM ','LB ',27.13,4,'T ','M ','U ',3,35,'Jul  1 2003 12:00AM',NULL,NULL,'C0009006-715F-4B76-A05A-1A0D3ADFB49A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (971,'Touring-2000 Blue, 50','BK-T44U-50',1,1,'Blue',100,75,755.15,1214.85,'50','CM ','LB ',27.42,4,'T ','M ','U ',3,35,'Jul  1 2003 12:00AM',NULL,NULL,'84ABDA8F-0007-4BCA-9A61-B2DEA58866C3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (972,'Touring-2000 Blue, 54','BK-T44U-54',1,1,'Blue',100,75,755.15,1214.85,'54','CM ','LB ',27.68,4,'T ','M ','U ',3,35,'Jul  1 2003 12:00AM',NULL,NULL,'6DCFE2A3-3555-44E4-9116-6F6DBE448B8B','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (973,'Road-350-W Yellow, 40','BK-R79Y-40',1,1,'Yellow',100,75,1082.51,1700.99,'40','CM ','LB ',15.35,4,'R ','M ','W ',2,27,'Jul  1 2003 12:00AM',NULL,NULL,'237B16D9-53F2-4FD4-BEFE-48209E57AEC3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (974,'Road-350-W Yellow, 42','BK-R79Y-42',1,1,'Yellow',100,75,1082.51,1700.99,'42','CM ','LB ',15.77,4,'R ','M ','W ',2,27,'Jul  1 2003 12:00AM',NULL,NULL,'80BD3F8B-42C7-43D8-91F5-9FB6175287AF','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (975,'Road-350-W Yellow, 44','BK-R79Y-44',1,1,'Yellow',100,75,1082.51,1700.99,'44','CM ','LB ',16.13,4,'R ','M ','W ',2,27,'Jul  1 2003 12:00AM',NULL,NULL,'0C61E8AF-003D-4E4B-B5B7-02F01A26BE26','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (976,'Road-350-W Yellow, 48','BK-R79Y-48',1,1,'Yellow',100,75,1082.51,1700.99,'48','CM ','LB ',16.42,4,'R ','M ','W ',2,27,'Jul  1 2003 12:00AM',NULL,NULL,'EC4284DC-85FA-44A8-89EC-77FC9B71720A','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (977,'Road-750 Black, 58','BK-R19B-58',1,1,'Black',100,75,343.65,539.99,'58','CM ','LB ',20.79,4,'R ','L ','U ',2,31,'Jul  1 2003 12:00AM',NULL,NULL,'87B81A1A-A5B5-43D2-A20D-0230800490B9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (978,'Touring-3000 Blue, 44','BK-T18U-44',1,1,'Blue',100,75,461.44,742.35,'44','CM ','LB ',28.77,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'4F638E15-2ED0-4193-90CE-47DA580E01DD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (979,'Touring-3000 Blue, 50','BK-T18U-50',1,1,'Blue',100,75,461.44,742.35,'50','CM ','LB ',29.13,4,'T ','L ','U ',3,36,'Jul  1 2003 12:00AM',NULL,NULL,'DE305B62-88FC-465B-B23D-D8C0F7E6D361','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (980,'Mountain-400-W Silver, 38','BK-M38S-38',1,1,'Silver',100,75,419.78,769.49,'38','CM ','LB ',26.35,4,'M ','M ','W ',1,22,'Jul  1 2003 12:00AM',NULL,NULL,'7A927632-99A4-4F24-ADCE-0062D2D113D9','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (981,'Mountain-400-W Silver, 40','BK-M38S-40',1,1,'Silver',100,75,419.78,769.49,'40','CM ','LB ',26.77,4,'M ','M ','W ',1,22,'Jul  1 2003 12:00AM',NULL,NULL,'0A72791C-A984-4733-AE4E-2B4373CFD7CD','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (982,'Mountain-400-W Silver, 42','BK-M38S-42',1,1,'Silver',100,75,419.78,769.49,'42','CM ','LB ',27.13,4,'M ','M ','W ',1,22,'Jul  1 2003 12:00AM',NULL,NULL,'4EA4FE06-AAEA-42D4-A9D9-69F6A9A4A042','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (983,'Mountain-400-W Silver, 46','BK-M38S-46',1,1,'Silver',100,75,419.78,769.49,'46','CM ','LB ',27.42,4,'M ','M ','W ',1,22,'Jul  1 2003 12:00AM',NULL,NULL,'0B0C8EE4-FF2D-438E-9CAC-464783B86191','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (984,'Mountain-500 Silver, 40','BK-M18S-40',1,1,'Silver',100,75,308.22,564.99,'40','CM ','LB ',27.35,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'B96C057B-6416-4851-8D59-BCB37C8E6E51','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (985,'Mountain-500 Silver, 42','BK-M18S-42',1,1,'Silver',100,75,308.22,564.99,'42','CM ','LB ',27.77,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'B8D1B5D9-8A39-4097-A04A-56E95559B534','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (986,'Mountain-500 Silver, 44','BK-M18S-44',1,1,'Silver',100,75,308.22,564.99,'44','CM ','LB ',28.13,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'E8CEC794-E8E2-4312-96A7-4832E573D3FC','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (987,'Mountain-500 Silver, 48','BK-M18S-48',1,1,'Silver',100,75,308.22,564.99,'48','CM ','LB ',28.42,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'77EF419F-481F-40B9-BDB9-7E6678E550E3','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (988,'Mountain-500 Silver, 52','BK-M18S-52',1,1,'Silver',100,75,308.22,564.99,'52','CM ','LB ',28.68,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'CAD60945-183E-4AB3-A70C-3F5BAC6BF134','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (989,'Mountain-500 Black, 40','BK-M18B-40',1,1,'Black',100,75,294.58,539.99,'40','CM ','LB ',27.35,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'28287157-3F06-487B-8531-BEE8A37329E4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (990,'Mountain-500 Black, 42','BK-M18B-42',1,1,'Black',100,75,294.58,539.99,'42','CM ','LB ',27.77,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'F5752C9C-56BA-41A7-83FD-139DA28C15FA','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (991,'Mountain-500 Black, 44','BK-M18B-44',1,1,'Black',100,75,294.58,539.99,'44','CM ','LB ',28.13,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'C7852127-2FB8-4959-B5A3-DE5A8D6445E4','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (992,'Mountain-500 Black, 48','BK-M18B-48',1,1,'Black',100,75,294.58,539.99,'48','CM ','LB ',28.42,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'75752E26-A3B6-4264-9B06-F23A4FBDC5A7','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (993,'Mountain-500 Black, 52','BK-M18B-52',1,1,'Black',100,75,294.58,539.99,'52','CM ','LB ',28.68,4,'M ','L ','U ',1,23,'Jul  1 2003 12:00AM',NULL,NULL,'69EE3B55-E142-4E4F-AED8-AF02978FBE87','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (994,'LL Bottom Bracket','BB-7421',1,1,NULL,500,375,23.97,53.99,NULL,NULL,'G  ',223.00,1,NULL,'L ',NULL,5,95,'Jul  1 2003 12:00AM',NULL,NULL,'FA3C65CD-0A22-47E3-BDF6-53F1DC138C43','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (995,'ML Bottom Bracket','BB-8107',1,1,NULL,500,375,44.95,101.24,NULL,NULL,'G  ',168.00,1,NULL,'M ',NULL,5,96,'Jul  1 2003 12:00AM',NULL,NULL,'71AB847F-D091-42D6-B735-7B0C2D82FC84','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (996,'HL Bottom Bracket','BB-9108',1,1,NULL,500,375,53.94,121.49,NULL,NULL,'G  ',170.00,1,NULL,'H ',NULL,5,97,'Jul  1 2003 12:00AM',NULL,NULL,'230C47C5-08B2-4CE3-B706-69C0BDD62965','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (997,'Road-750 Black, 44','BK-R19B-44',1,1,'Black',100,75,343.65,539.99,'44','CM ','LB ',19.77,4,'R ','L ','U ',2,31,'Jul  1 2003 12:00AM',NULL,NULL,'44CE4802-409F-43AB-9B27-CA53421805BE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (998,'Road-750 Black, 48','BK-R19B-48',1,1,'Black',100,75,343.65,539.99,'48','CM ','LB ',20.13,4,'R ','L ','U ',2,31,'Jul  1 2003 12:00AM',NULL,NULL,'3DE9A212-1D49-40B6-B10A-F564D981DBDE','Mar 11 2004 10:01AM')
Insert Into [Product] ([ProductID],[Name],[ProductNumber],[MakeFlag],[FinishedGoodsFlag],[Color],[SafetyStockLevel],[ReorderPoint],[StandardCost],[ListPrice],[Size],[SizeUnitMeasureCode],[WeightUnitMeasureCode],[Weight],[DaysToManufacture],[ProductLine],[Class],[Style],[ProductSubcategoryID],[ProductModelID],[SellStartDate],[SellEndDate],[DiscontinuedDate],[rowguid],[ModifiedDate]) Values (999,'Road-750 Black, 52','BK-R19B-52',1,1,'Black',100,75,343.65,539.99,'52','CM ','LB ',20.42,4,'R ','L ','U ',2,31,'Jul  1 2003 12:00AM',NULL,NULL,'AE638923-2B67-4679-B90E-ABBAB17DCA31','Mar 11 2004 10:01AM')


Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (1,'Classic Vest',NULL,NULL,'29321D47-1E4C-4AAC-887C-19634328C25E','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (2,'Cycling Cap',NULL,NULL,'474FB654-3C96-4CB9-82DF-2152EEFFBDB0','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (3,'Full-Finger Gloves',NULL,NULL,'A75483FE-3C47-4AA4-93CF-664B51192987','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (4,'Half-Finger Gloves',NULL,NULL,'14B56F2A-D4AA-40A4-B9A2-984F165ED702','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (5,'HL Mountain Frame',NULL,NULL,'FDD5407B-C2DB-49D1-A86B-C13A2E3582A2','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (6,'HL Road Frame',NULL,NULL,'4D332ECC-48B3-4E04-B7E7-227F3AC2A7EC','May  2 1998 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (7,'HL Touring Frame',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesFR-210B Instructions for Manufacturing HL Touring Frame. Summary: This document contains manufacturing instructions for manufacturing the HL Touring Frame, Product Model 7. Instructions are work center specific and are identified by Work Center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="2.5" LotSize="100" MachineHours="3" SetupHours="0.5" LocationID="10">
                    Work Center 10 - Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .5, Labor Hours = 2.5, Machine Hours = 3, Lot Sizing = 100)<step>
                        Insert <material>aluminum sheet MS-2341</material> into the <tool>T-85A framing tool</tool>.
                    </step><step>
                        Attach <tool>Trim Jig TJ-26</tool> to the upper and lower right corners of the aluminum sheet.
                    </step><step>
                        Using a <tool>router with a carbide tip 15</tool>, route the aluminum sheet following the jig carefully.
                    </step><step>
                        Insert the frame into <tool>Forming Tool FT-15</tool> and press Start.
                    </step><step>
                        When finished, inspect the forms for defects per Inspection Specification <specs>INFS-111</specs>.
                    </step><step>Remove the frames from the tool and place them in the Completed or Rejected bin as appropriate.</step></Location><Location LaborHours="1.75" LotSize="1" MachineHours="2" SetupHours="0.15" LocationID="20">
                    Work Center 20 - Frame Welding. The following instructions pertain to Work Center 20. (Setup hours = .15, Labor Hours = 1.75, Machine Hours = 2, Lot Sizing = 1)<step>
                        Assemble all frame components following blueprint <blueprint>1299</blueprint>.
                    </step><step>
                        Weld all frame components together as shown in illustration <diag>3</diag></step><step>
                        Inspect all weld joints per Adventure Works Cycles Inspection Specification <specs>INFS-208</specs>.
                    </step></Location><Location LaborHours="1" LotSize="1" LocationID="30">
                    Work Center 30 - Debur and Polish. The following instructions pertain to Work Center 30. (Setup hours = 0, Labor Hours = 1, Machine Hours = 0, Lot Sizing = 1)<step>
                        Using the <tool>standard debur tool</tool>, remove all excess material from weld areas.
                    </step><step>
                        Using <material>Acme Polish Cream</material>, polish all weld areas.
                    </step></Location><Location LaborHours="0.5" LotSize="20" MachineHours="0.65" LocationID="45">
                    Work Center 45 - Specialized Paint. The following instructions pertain to Work Center 45. (Setup hours = 0, Labor Hours = .5, Machine Hours = .65, Lot Sizing = 20)<step>
                        Attach <material>a maximum of 20 frames</material> to <tool>paint harness</tool> ensuring frames are not touching.
                    </step><step>
                        Mix <material>primer PA-529S</material>. Test spray pattern on sample area and correct flow and pattern as required per engineering spec <specs>AWC-501</specs>.
                    </step><step>Apply thin coat of primer to all surfaces.  </step><step>After 30 minutes, touch test for dryness. If dry to touch, lightly sand all surfaces. Remove all surface debris with compressed air. </step><step>
                        Mix <material>paint</material> per manufacturer instructions.
                    </step><step>
                        Test spray pattern on sample area and correct flow and pattern as required per engineering spec <specs>AWC-509</specs>.
                    </step><step>Apply thin coat of paint to all surfaces. </step><step>After 60 minutes, touch test for dryness. If dry to touch, reapply second coat. </step><step>
                        Allow paint to cure for 24 hours and inspect per <specs>AWC-5015</specs>.
                    </step></Location><Location LaborHours="3" LotSize="1" SetupHours="0.25" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .25, Labor Hours = 3, Machine Hours = 0, Lot Sizing = 1)<step>Add Seat Assembly. </step><step>Add Brake assembly.   </step><step>Add Wheel Assembly. </step><step>Inspect Front Derailleur. </step><step>Inspect Rear Derailleur. </step></Location><Location LaborHours="4" LotSize="1" LocationID="60">
                    Work Center 60 - Final Assembly. The following instructions pertain to Work Center 60. (Setup hours = 0, Labor Hours = 4, Machine Hours = 0, Lot Sizing = 1)<step>
                        Perform final inspection per engineering specification <specs>AWC-915</specs>.
                    </step><step>Complete all required certification forms.</step><step>Move to shipping.</step></Location></root>','D60ED2A5-C100-4C54-89A1-531404C4A20F','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (8,'LL Mountain Frame',NULL,NULL,'65BF3F6D-BCF2-4DB6-8515-FC5C57423037','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (9,'LL Road Frame',NULL,NULL,'DDC67A2F-024A-4446-9B54-3C679BABA708','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (10,'LL Touring Frame',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesFR-200A Instructions for Manufacturing LL Touring Frame Summary: This document contains manufacturing instructions for manufacturing the LL Touring Frame, Product Model 10. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="2" LotSize="100" MachineHours="2" SetupHours="0.1" LocationID="10">
                    Work Center 10 - Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .10, Labor Hours = 2, Machine Hours = 2, Lot Sizing = 100)<step>
                        Insert <material>aluminum sheet MS-6061</material> into tool <tool>T-99 framing tool</tool>.
                    </step><step>
                        Attach <tool>Trim Jig TJ-25</tool> to the upper and lower right corners of the aluminum sheet.
                    </step><step>
                        Using a <tool>router with a carbide tip 26</tool>, route the aluminum sheet following the jig carefully.
                    </step><step>
                        Insert the frame into <tool>Forming Tool FT-25</tool> and press Start.
                    </step><step>
                        When finished, inspect the form for defects per <specs>Inspection Specification INFS-110</specs>.
                    </step><step>Remove the frame from the tool and place it in the Completed or Rejected bin as appropriate.</step></Location><Location LaborHours="1.5" LotSize="1" MachineHours="1.75" SetupHours="0.25" LocationID="20">
                    Work Center 20 - Frame Welding. The following instructions pertain to Work Center 20. (Setup hours = .25, Labor Hours = 1.5, Machine Hours = 1.75, Lot Sizing = 1)<step>
                        Assemble all frame components following blueprint <blueprint>12345</blueprint>.
                    </step><step>
                        Weld all frame components together as shown in illustration <diag>3</diag></step><step>
                        Inspect all weld joints per Adventure Works Cycles Inspection Specification <specs>INFS-206</specs>.
                    </step></Location><Location LaborHours="1" LotSize="1" LocationID="30">
                    Work Center 30 - Debur and Polish. The following instructions pertain to Work Center 30. (Setup hours = 0, Labor Hours = 1, Machine Hours = 0, Lot Sizing = 1)<step>
                        Using the <tool>standard debur tool</tool>, remove all excess material from weld areas.
                    </step><step>
                        Using <material>Acme Polish Cream</material>, polish all weld areas.
                    </step></Location><Location LaborHours="1.5" LotSize="20" LocationID="4">
                    Work Center 40 - Paint. The following instructions pertain to Work Center 40. (Setup hours = 0, Labor Hours = 1.5, Machine Hours = 0, Lot Sizing = 20)<step>
                        Attach a <material>maximum of 20 frames</material> to paint harness ensuring frames are not touching.
                    </step><step>
                        Mix <material>primer PA-345</material>. Test spray pattern on sample area and correct flow and pattern as required per engineering spec <specs>AWC-502</specs>.
                    </step><step>Apply thin coat of primer to all surfaces.  </step><step>
                        After 30 minutes, touch test for dryness. If dry to touch, lightly sand all surfaces. Remove all surface debris with <material>compressed air</material>.
                    </step><step>
                        Mix <material>paint</material> per manufacturer instructions.
                    </step><step>
                        Test spray pattern on sample area and correct flow and pattern as required per engineering specification<specs>AWC-503</specs>.
                    </step><step>Apply thin coat of paint to all surfaces. </step><step>After 60 minutes, touch test for dryness. If dry to touch, reapply second coat. </step><step>
                        Allow paint to cure for 24 hours and inspect per <specs>AWC-5010</specs>.
                    </step></Location><Location LaborHours="3" LotSize="1" SetupHours="0.25" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .25, Labor Hours = 3, Machine Hours = 0, Lot Sizing = 1)<step>
                        Add <material>Seat Assembly</material>.
                    </step><step>
                        Add <material>Brake assembly</material>.
                    </step><step>
                        Add <material>Wheel Assembly</material>.
                    </step><step>Inspect Front Derailleur. </step><step>Inspect Rear Derailleur.</step></Location><Location LaborHours="4" LotSize="1" LocationID="60">
                    Work Center 60 - Final Assembly. The following instructions pertain to Work Center 60. (Setup hours = 0, Labor Hours = 4, Machine Hours = 0, Lot Sizing = 1)<step>
                        Perform final inspection per engineering specification <specs>AWC-910</specs>.
                    </step><step>Complete all required certification forms.</step><step>Move to shipping.</step></Location></root>','66C63844-2A24-473C-96D5-D3B3FD57D834','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (11,'Long-Sleeve Logo Jersey',NULL,NULL,'20EFE3F1-A2F8-4DDE-B74B-18265F61F863','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (12,'Men''s Bib-Shorts',NULL,NULL,'219E2F87-26A9-483B-B968-04578E943096','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (13,'Men''s Sports Shorts',NULL,NULL,'45FE0D77-6645-473C-A116-1232BAEA8D43','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (14,'ML Mountain Frame',NULL,NULL,'0D48C51D-7603-4010-9265-0491805BB010','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (15,'ML Mountain Frame-W',NULL,NULL,'AA77697C-6D1C-48F1-845C-3CB089498715','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (16,'ML Road Frame',NULL,NULL,'3494E8FF-7DAF-4860-ABF6-97842048E272','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (17,'ML Road Frame-W',NULL,NULL,'CA18ECFD-2023-4FA7-A556-0321153BCA34','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (18,'Mountain Bike Socks',NULL,NULL,'36B1A76A-DFF3-4A55-86F9-65EB1CB18D7B','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (19,'Mountain-100','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="19" ProductModelName="Mountain 100"><p1:Summary><html:p>Our top-of-the-line competition mountain bike. 
 				Performance-enhancing options include the innovative HL Frame, 
				super-smooth front suspension, and traction for all terrain.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>These are the product highlights. 
                 <wm:Warranty><wm:WarrantyPeriod>3 years</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>10 years</wm:NoOfYears><wm:Description>maintenance contract available through your dealer or any AdventureWorks retail store.</wm:Description></wm:Maintenance><wf:wheel>High performance wheels.</wf:wheel><wf:saddle><html:i>Anatomic design</html:i> and made from durable leather for a full-day of riding in comfort.</wf:saddle><wf:pedal><html:b>Top-of-the-line</html:b> clipless pedals with adjustable tension.</wf:pedal><wf:BikeFrame>Each frame is hand-crafted in our Bothell facility to the optimum diameter 
				and wall-thickness required of a premium mountain frame. 
				The heat-treated welded aluminum frame has a larger diameter tube that absorbs the bumps.</wf:BikeFrame><wf:crankset> Triple crankset; alumunim crank arm; flawless shifting. </wf:crankset></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>118</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   <Material>Almuminum Alloy</Material><Color>Available in most colors</Color><ProductLine>Mountain bike</ProductLine><Style>Unisex</Style><RiderExperience>Advanced to Professional riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'FCA0665B-B956-489A-A5EC-6F0B4AA14D02','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (20,'Mountain-200',NULL,NULL,'3B78EDFF-2AA9-4AC1-8C3D-94090B5F53A9','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (21,'Mountain-300',NULL,NULL,'ECDDD0D7-2DB2-464D-B2DA-89BFFC6276AA','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (22,'Mountain-400-W',NULL,NULL,'6D2FCCE4-FFCE-4662-A3F8-5D18F0EEDCD8','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (23,'Mountain-500','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="23" ProductModelName="Mountain-500"><p1:Summary><html:p>Suitable for any type of riding, on or off-road. 
			Fits any budget. Smooth-shifting with a comfortable ride.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>Product highlights include: 
                 <wm:Warranty><wm:WarrantyPeriod>1 year</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>3 years</wm:NoOfYears><wm:Description>maintenance contact available through dealer</wm:Description></wm:Maintenance><wf:wheel>Stable, durable wheels suitable for novice riders.</wf:wheel><wf:saddle>Made from synthetic leather and features gel padding for increased comfort.</wf:saddle><wf:pedal><html:b>Expanded platform</html:b> so you can ride in any shoes; great for all-around riding.</wf:pedal><wf:crankset> Super rigid spindle. </wf:crankset><wf:BikeFrame>Our best value frame utilizing the same, ground-breaking technology as the ML aluminum frame.</wf:BikeFrame></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>1</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   <Height>Varies</Height> Centimeters.
                   <Material>Aluminum Alloy</Material><Color>Available in all colors.</Color><ProductLine>Mountain bike</ProductLine><Style>Unisex</Style><RiderExperience>Novice to Intermediate riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'866DBAD3-5999-4329-BEAC-D826D959D9A1','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (24,'Racing Socks',NULL,NULL,'BD8BA6F8-7E16-4FA3-B3B3-2036DD4A2AE0','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (25,'Road-150','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="25" ProductModelName="Road-150"><p1:Summary><html:p>This bike is ridden by race winners. Developed with the 
			Adventure Works Cycles professional race team, it has a extremely light 
			heat-treated aluminum frame, and steering that allows precision control.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>These are the product highlights. 
                 <wm:Warranty><wm:WarrantyPeriod>4 years</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>7 years</wm:NoOfYears><wm:Description>maintenance contact available through dealer or any Adventure Works Cycles retail store.</wm:Description></wm:Maintenance><wf:handlebar>Designed for racers; high-end anatomically shaped bar from aluminum alloy.</wf:handlebar><wf:wheel>Strong wheels with double-walled rims.</wf:wheel><wf:saddle><html:i>Lightweight </html:i> kevlar racing saddle.</wf:saddle><wf:pedal><html:b>Top-of-the-line</html:b> clipless pedals with adjustable tension.</wf:pedal><wf:BikeFrame><html:i>Our lightest and best quality </html:i> aluminum frame made from the newest alloy;
			it is welded and heat-treated for strength. 
			Our innovative design results in maximum comfort and performance.</wf:BikeFrame></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>126</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   <Material>Aluminum</Material><Color>Available in all colors.</Color><ProductLine>Road bike</ProductLine><Style>Unisex</Style><RiderExperience>Intermediate to Professional riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'94FFB702-0CBC-4E3F-B840-C51F0D11C8F6','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (26,'Road-250',NULL,NULL,'3770C5E3-8DC9-43C7-B735-7AFF21645D96','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (27,'Road-350-W',NULL,NULL,'DFE49035-7720-4FF4-B28B-16250EE46259','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (28,'Road-450','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="28" ProductModelName="Road-450"><p1:Summary><html:p>A true multi-sport bike that offers streamlined riding and a revolutionary design. 
			       Aerodynamic design lets you ride with the pros, and the gearing will conquer hilly roads.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>These are the product highlights. 
                 <wm:Warranty><wm:WarrantyPeriod>1 year</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>5 years</wm:NoOfYears><wm:Description>maintenance contact available through dealer</wm:Description></wm:Maintenance><wf:handlebar><html:i>Incredibly strong</html:i> professional grade handlebar.</wf:handlebar><wf:wheel>Aluminum alloy rim with stainless steel spokes; built for speed on our high quality rubber tires.</wf:wheel><wf:saddle><html:i>Comfortable</html:i> saddle with bump absorping rubber bumpers.</wf:saddle><wf:pedal><html:b>Top-of-the-line</html:b> clipless pedals with adjustable tension.</wf:pedal><wf:BikeFrame><html:i>aluminum alloy </html:i> frame
                     and features a lightweight down-tube milled to the perfect diameter for optimal strength.</wf:BikeFrame></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>111</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   <Height>Varies</Height> Centimeters.
                   <Material>Aluminum Alloy</Material><Weight>Varies with size </Weight><Color>Available in all colors.</Color><ProductLine>Road bike</ProductLine><Style>Unisex</Style><RiderExperience>Novice to Advanced riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'8456BB94-B4DD-4A47-A76B-D0E54AB4285D','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (29,'Road-550-W',NULL,NULL,'F85F84F2-9CE0-4ECC-9C29-E78021FFC877','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (30,'Road-650',NULL,NULL,'42E1C597-6DD9-4071-B1A5-1DC5CDCBDBCA','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (31,'Road-750',NULL,NULL,'2BF795F4-2666-4691-AF14-D490C7334A8A','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (32,'Short-Sleeve Classic Jersey',NULL,NULL,'6BECCF2D-EACD-496B-995B-D692567565CD','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (33,'Sport-100',NULL,NULL,'47F7C450-D16A-4CEA-BE6E-2D6C8C8F81EE','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (34,'Touring-1000','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="34" ProductModelName="Touring-1000"><p1:Summary><html:p>Travel in style and comfort. Designed for maximum comfort and safety. 
			Wide gear range takes on all hills. High-tech aluminum alloy construction provides durability without added weight.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>These are the product highlights. 
                 <wm:Warranty><wm:WarrantyPeriod>1 year</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>5 years</wm:NoOfYears><wm:Description>maintenance contact available through dealer</wm:Description></wm:Maintenance><wf:handlebar>A light yet stiff aluminum bar for long distance riding.</wf:handlebar><wf:wheel>Excellent aerodynamic rims guarantee a smooth ride.</wf:wheel><wf:saddle><html:i>Cut-out shell </html:i> for a more comfortable ride.</wf:saddle><wf:pedal>A stable pedal for all-day riding.</wf:pedal><wf:BikeFrame><html:i>aluminum alloy </html:i> frame
                     and features a lightweight down-tube milled to the perfect diameter for optimal strength.</wf:BikeFrame></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>87</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   
                   <Material>Aluminum alloy </Material><Color>Available in most colors.</Color><ProductLine>Touring bike</ProductLine><Style>Unisex</Style><RiderExperience>Novice to Advanced riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'52E7F2C1-DBFF-4518-927D-C7D46F9ED32E','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (35,'Touring-2000','<?xml-stylesheet href="ProductDescription.xsl" type="text/xsl"?><p1:ProductDescription xmlns:p1="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelDescription" xmlns:wm="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelWarrAndMain" xmlns:wf="http://www.adventure-works.com/schemas/OtherFeatures" xmlns:html="http://www.w3.org/1999/xhtml" ProductModelID="35" ProductModelName="Touring-2000"><p1:Summary><html:p>The plush custom saddle keeps you riding all day, and there''s plenty of space
			 to add panniers and bike bags to the newly-redesigned carrier. 
				This bike has great stability when fully-loaded.
                        </html:p></p1:Summary><p1:Manufacturer><p1:Name>AdventureWorks</p1:Name><p1:Copyright>2002</p1:Copyright><p1:ProductURL>HTTP://www.Adventure-works.com</p1:ProductURL></p1:Manufacturer><p1:Features>These are the product highlights. 
                 <wm:Warranty><wm:WarrantyPeriod>1 year</wm:WarrantyPeriod><wm:Description>parts and labor</wm:Description></wm:Warranty><wm:Maintenance><wm:NoOfYears>5 years</wm:NoOfYears><wm:Description>maintenance contact available through dealer</wm:Description></wm:Maintenance><wf:handlebar>A light yet stiff aluminum bar for long distance riding.</wf:handlebar><wf:saddle><html:i>New design </html:i> relieves pressure for long rides.</wf:saddle><wf:pedal><html:b>Top-of-the-line</html:b> clipless pedals with adjustable tension.</wf:pedal><wf:crankset> High-strength crank arm. </wf:crankset><wf:BikeFrame>The aluminum frame is custom-shaped for both good looks and strength; 
				it will withstand the most rigorous challenges of daily riding.</wf:BikeFrame></p1:Features><!-- add one or more of these elements... one for each specific product in this product model --><p1:Picture><p1:Angle>front</p1:Angle><p1:Size>small</p1:Size><p1:ProductPhotoID>87</p1:ProductPhotoID></p1:Picture><!-- add any tags in <specifications> --><p1:Specifications> These are the product specifications.
                   <Material>Aluminum</Material><Color>Available in all colors except metallic.</Color><ProductLine>Touring bike</ProductLine><Style>Men''s</Style><FrameMaterial>Aluminium alloy</FrameMaterial><RiderExperience>Intermediate to Advanced riders</RiderExperience></p1:Specifications></p1:ProductDescription>',NULL,'AA10D9E6-E33F-4DA8-ACE1-992FCD6BB171','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (36,'Touring-3000',NULL,NULL,'F5A6EC78-4451-45DB-955F-DB197DE8B059','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (37,'Women''s Mountain Shorts',NULL,NULL,'A08DD61A-6155-4051-9A11-223232EA51CD','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (38,'Women''s Tights',NULL,NULL,'A96FF80D-D52A-432F-9701-731BEF16EFCC','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (39,'Mountain-400',NULL,NULL,'37D261A7-00CF-4880-AC1A-533B6B4365B0','Jun  1 2001 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (40,'Road-550',NULL,NULL,'30450264-4AB8-45E0-8BB5-4D407EA2950A','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (41,'Road-350',NULL,NULL,'D71BD21C-239E-4C2B-98A3-101962D6B2D3','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (42,'LL Mountain Front Wheel',NULL,NULL,'AA977B32-ACD8-4C53-A560-88A02AC1954D','Nov 20 2002  9:56AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (43,'Touring Rear Wheel',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-150C Instructions for Assembling Touring Front Wheel Summary: This document contains manufacturing instructions for assembling the Touring Front Wheel, Product Model 43. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="3" LotSize="1" LocationID="50">
                    Work Center - 50 Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .0, Labor Hours = 3, Machine Hours = 0, Lot Sizing = 1)<step>
                        Inspect the <material>rim</material> for dents, cracks or other damage.
                    </step><step>
                        Slide each <material>spoke</material> through the <material>hub flange</material> working in a clockwise direction.
                    </step><step>
                        For each spoke, screw on the <material>spoke nipple (NI-9522)</material>. Do not over tighten.
                    </step><step>
                        Place the <material>wheel</material> in the truing stand.
                    </step><step>Pluck each spoke. The sound from each spoke should be consistent. Adjust as needed. </step><step>
                        Inflate the <material>tire tube</material>to one-quarter pressure.
                    </step><step>
                        Insert the <material>valve stem</material> through <material>Rim RM-M823</material>.
                    </step><step>Tuck the tube into the tire ensuring there are no wrinkles or kinks.</step><step>Inflate the tube to half pressure. </step><step>Spin the wheel and ensure the bead line is just above the rim. </step><step>Inflate the tube to 35 PSI.</step><step>
                        Attach reflector as shown in illustration <diag>7</diag></step></Location></root>','E878FCAA-61CC-4014-988A-51F52643F7AA','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (44,'Touring Front Wheel',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-151C Instructions for Assembling Touring Rear Wheel Summary: This document contains manufacturing instructions for assembling the Touring Rear Wheel, Product Model 44. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="3" LotSize="1" LocationID="50">
                    Work Center - 50 Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .0, Labor Hours = 3, Machine Hours = 0, Lot Sizing = 1)<step>
                        Inspect the <material>rim</material> for dents, cracks or other damage.
                    </step><step>
                        Slide each <material>spoke</material> through the <material>hub flange</material> working in a clockwise direction.
                    </step><step>
                        For each spoke, screw on the <material>spoke nipple (NI-9525)</material>. Do not over tighten.
                    </step><step>
                        Place the wheel in the <tool>truing stand</tool>.
                    </step><step>Pluck each spoke. The sound from each spoke should be consistent. Adjust as needed.</step><step>Inflate the tire tube to one-quarter pressure.</step><step>
                        Insert the <material>valve stem</material> through <material>Rim RM-M825</material>.
                    </step><step>Tuck the tube into the tire ensuring there are no wrinkles or kinks.</step><step>Inflate the tube to half pressure. </step><step>Spin the wheel and ensure the bead line is just above the rim.</step><step>Inflate the tube to 35 PSI.</step></Location></root>','6DA78798-3793-4B8E-829E-DBA9D140B1D4','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (45,'ML Mountain Front Wheel',NULL,NULL,'C3FF3F93-60A8-4957-B076-B7D0984EE70F','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (46,'HL Mountain Front Wheel',NULL,NULL,'CCA597FB-195F-4EC5-BF5C-15B98D176F4C','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (47,'LL Touring Handlebars',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-190A Instructions for Manufacturing and Assembling the LL Touring Handlebars Summary: This document contains manufacturing instructions for manufacturing and assembling the LL Touring Handlebars, Product Model 47. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="1" LotSize="100" MachineHours="2" SetupHours="0.1" LocationID="10">
                    Work Center 10 - Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .10, Labor Hours = 1, Machine Hours = 2, Lot Sizing = 100)<step>
                        Insert <material>aluminum sheet MS-2259</material> into tool <tool>T-50 Tube Forming tool</tool>.
                    </step><step>
                        Attach <tool>Trim Jig TJ-8</tool> to the upper and lower right corners of the aluminum sheet.
                    </step><step>Route the aluminum sheet following the jig carefully. </step><step>
                        Insert the cut pieces into <tool>Tube Forming Tool FT-90</tool> and press Start.
                    </step><step>
                        When finished, inspect the form for defects per Inspection Specification <specs>INFS-90</specs>.
                    </step><step>Remove the lengths of tube from the tool and place it in the Completed or Rejected bin as appropriate.</step></Location><Location LaborHours="1" LotSize="1" MachineHours="1.75" SetupHours="0.25" LocationID="20">
                    Work Center 20 - Frame Welding. The following instructions pertain to Work Center 20. (Setup hours = .25, Labor Hours = 1.0, Machine Hours = 1.75, Lot Sizing = 1)<step>
                        Assemble all <material>handlebar components</material> following blueprint <blueprint>1111</blueprint>.
                    </step><step>
                        Weld all components together as shown in illustration <diag>5</diag></step><step>
                        Inspect all weld joints per Adventure Works Cycles Inspection Specification <specs>INFS-222</specs>.
                    </step></Location><Location LaborHours="3.5" LotSize="1" LocationID="50">
                    Work Center - 50 Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .0, Labor Hours = 3.5, Machine Hours = 0, Lot Sizing = 1)<step>
                        Slide the <material>stem</material> onto the <material>handlebar</material> centering it over the knurled section.
                    </step><step>Take care not to scratch the handlebar.</step><step>The ends of the handlebar should turn toward the rear. </step><step>
                        Attach the <material>Pinch Bolt (Product Number PB-6109)</material>, <material>Lock Washer 10 (Product Number LW-1210)</material>, and <material>Lock Nut 7 (Product Number LN-1224)</material> onto the stem.
                    </step><step>Tighten the nut just enough to keep the handlebar from rotating in the stem. Do not over tighten. </step><step>
                        Put a <material>Flat Washer 1 (Product Number FW-1000)</material> onto the stem bolt, and then insert the bolt down into the stem.
                    </step><step>
                        Thread the plug nut onto the stem bolt aligning it with the stem body as shown in illustration <diag>4</diag>. Insert the stem down into the lock nut until the minimum insertion line marked on the stem is hidden inside the nut.
                    </step><step>
                        Attach the <material>grips</material>.
                    </step><step>
                        Inspect per specification <specs>FI-225</specs>.
                    </step></Location></root>','84138622-1EA6-489F-9C98-6E3924CFBAC0','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (48,'HL Touring Handlebars',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-190A Instructions for Manufacturing and Assembling the HL Touring Handlebars Summary: This document contains manufacturing instructions for manufacturing and assembling the HL Touring Handlebars, Product Model 48. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="1" LotSize="100" MachineHours="2.5" SetupHours="0.1" LocationID="10">
                    Work Center 10 - Frame Forming. The following instructions pertain to Work Center 10. (Setup hours = .10, Labor Hours = 1, Machine Hours = 2.5, Lot Sizing = 100)<step>
                        Insert <material>aluminum sheet MS-2259</material> into tool <tool>T-51 Tube Forming tool</tool>.
                    </step><step>
                        Attach <tool>Trim Jig TJ-9</tool> to the upper and lower right corners of the aluminum sheet.
                    </step><step>Route the aluminum sheet following the jig carefully. </step><step>
                        Insert the cut pieces into <tool>Tube Forming Tool FT-91</tool> and press Start.
                    </step><step>
                        When finished, inspect the form for defects per Inspection Specification <specs>INFS-90</specs>.
                    </step><step>Remove the lengths of tube from the tool and place it in the Completed or Rejected bin as appropriate.</step></Location><Location LaborHours="1" LotSize="1" MachineHours="2" SetupHours="0.25" LocationID="20">
                    Work Center 20 - Frame Welding. The following instructions pertain to Work Center 20. (Setup hours = .25, Labor Hours = 1.0, Machine Hours = 2, Lot Sizing = 1)<step>
                        Assemble all handlebar components following blueprint <blueprint>1112</blueprint>.
                    </step><step>
                        Using <tool>weld torch</tool>, weld all components together as shown in illustration <diag>5</diag></step><step>
                        Inspect all weld joints per Adventure Works Cycles Inspection Specification <specs>INFS-222</specs>.
                    </step></Location><Location LaborHours="3.5" LotSize="1" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .0, Labor Hours = 3.5, Machine Hours = 0, Lot Sizing = 1)<step>
                        Slide the <material>stem</material> onto the <material>handlebar</material> centering it over the knurled section.
                    </step><step>Take care not to scratch the handlebar.</step><step>The ends of the handlebar should turn toward the rear. </step><step>
                        Attach the <material>Pinch Bolt (Product Number PB-6109)</material>, <material>Lock Washer 7 (Product Number LI-3800)</material>, and <material>Lock Nut 16 (Product Number LN-1213)</material> onto the stem.
                    </step><step>Tighten the nut just enough to keep the handlebar from rotating in the stem. Do not over tighten. </step><step>
                        Put a <material>Flat Washer 9 (Product Number FW-3400)</material> onto the <material>stem bolt</material>, and then insert the bolt down into the stem.
                    </step><step>
                        Thread the plug nut onto the stem bolt aligning it with the stem body as shown in illustration <diag>4</diag>. Insert the stem down into the lock nut until the minimum insertion line marked on the stem is hidden inside the nut.
                    </step><step>
                        Attach the <material>grips</material>.
                    </step><step>
                        Inspect per specification <specs>FI-225</specs>.
                    </step></Location></root>','9DA82E49-80AD-4918-9A54-31F4B0C8EABB','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (49,'LL Road Front Wheel',NULL,NULL,'90F759C1-2073-4D9F-854B-C6B6F3BF9162','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (50,'ML Road Front Wheel',NULL,NULL,'980C8CD0-4903-41F2-9FFC-773C7FE4C254','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (51,'HL Road Front Wheel',NULL,NULL,'02A562E2-4DFA-4778-BBAC-BBDDCECF99B0','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (52,'LL Mountain Handlebars',NULL,NULL,'699C2AC5-5406-46D2-863D-DCFB23FC7943','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (53,'Touring Pedal',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-500 Instructions Assembling the Touring Pedal Summary: This document contains manufacturing instructions for assembling the Touring Pedal, Product Model 53. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="0.5" LotSize="1" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .0, Labor Hours = .5, Machine Hours = 0, Lot Sizing = 1)<step>
                        Visually examine the pedal spindles to determine <material>left and right pedals</material>. The left and right pedals have different threading directions. It is important you identify them correctly.
                    </step><step>
                        Apply a small amount of <material>grease</material> to the left pedal and thread the pedal onto the <material>left crank arm</material> by hand.
                    </step><step>If the threads do not turn easily, back the spindle out and re-start.</step><step>
                        Securely tighten the spindle against the crank arm using a <tool>small wrench</tool>.
                    </step><step>Apply a small amount of grease to the right pedal and thread the pedal onto the right crank arm by hand.</step><step>If the threads do not turn easily, back the spindle out and re-start.</step><step>Securely tighten the spindle against the crank arm using a small wrench.</step><step>
                        Inspect per specification <specs>FI-520</specs>.
                    </step></Location></root>','B98A3207-56FC-405C-A040-3C7A90CC7890','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (54,'ML Mountain Handlebars',NULL,NULL,'C9FCC804-2CD7-4B8A-B186-9C409CC19DF9','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (55,'HL Mountain Handlebars',NULL,NULL,'782C991B-A660-4561-A3F4-9BBD74259747','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (56,'LL Road Handlebars',NULL,NULL,'A7E65199-84A8-437E-AD55-360C1DF1D788','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (57,'ML Road Handlebars',NULL,NULL,'02200AA0-C369-4D77-A67C-75973EFDA81B','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (58,'HL Road Handlebars',NULL,NULL,'2489DDC5-1C89-4DEC-AF22-B0112CCEC467','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (59,'LL Headset',NULL,NULL,'39AFBBA9-0F6C-44EE-B5E1-32FA93F897E6','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (60,'ML Headset',NULL,NULL,'6BA9F3B6-E08B-4AC2-A725-B41114C2A283','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (61,'HL Headset',NULL,NULL,'E196D02E-9BF6-4C67-B772-ED9F86CCF44C','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (62,'LL Mountain Pedal',NULL,NULL,'8123F7E2-A5F4-4047-B69D-E74313DFEBCE','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (63,'ML Mountain Pedal',NULL,NULL,'BE9CDC56-F4AB-40F1-B338-2E08E0627ABD','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (64,'HL Mountain Pedal',NULL,NULL,'8DA73708-8DAE-44AE-AC6C-6E37022C1FFE','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (65,'ML Touring Seat/Saddle',NULL,NULL,'63A2199F-F5B5-49BD-BCFC-BEC1D1D16D8B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (66,'LL Touring Seat/Saddle',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-620 Instructions Assembling the LL Touring Seat Summary: This document contains manufacturing instructions for assembling the LL Touring Seat, Product Model 63. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="1.5" LotSize="1" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .0, Labor Hours = 1.5, Machine Hours = 0, Lot Sizing = 1)<step>
                        Put the <material>Seat post Lug (Product Number SL-0931)</material> on the <material>Seat Post (Product Number SP-2981)</material>.
                    </step><step>
                        Insert the <material>Pinch Bolt (Product Number PB-6109)</material> and tighten until it is secure but still able to slide up or down the post as shown in illustration <diag>6</diag>.
                    </step><step>
                        Attach the <material>LL Seat (Product Number SE-T312)</material> to the top of the Seat Post and tighten securely.
                    </step><step>
                        Inspect per specification <specs>FI-620</specs>.
                    </step></Location></root>','4A17C43A-1A55-41BB-BC97-612F47CEDEB3','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (67,'HL Touring Seat/Saddle',NULL,'<root xmlns="http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/ProductModelManuInstructions">
                Adventure Works CyclesWA-620 Instructions Assembling the HL Touring Seat Summary: This document contains manufacturing instructions for assembling the HL Touring Seat, Product Model 67. Instructions are work center specific and are identified by work center ID. These instructions must be followed in the order presented. Deviation from the instructions is not permitted unless an authorized Change Order detailing the deviation is provided by the Engineering Manager.<Location LaborHours="1" LotSize="1" SetupHours="0.25" LocationID="50">
                    Work Center 50 - SubAssembly. The following instructions pertain to Work Center 50. (Setup hours = .25, Labor Hours = 1, Machine Hours = 0, Lot Sizing = 1)<step>
                        Put the <material>Seatpost Lug (Product Number SL-0932)</material> on the <material>Seat Post (Product Number SP-3981)</material>.
                    </step><step>
                        Insert the <material>Pinch Bolt (Product Number PB-6109)</material> and tighten until it is secure but still able to slide up or down the post. See illustration <diag>6</diag>.
                    </step><step>
                        Attach the <material>HL Seat (Product Number SE-T315)</material> to the top of the Seat Post and tighten securely.
                    </step><step>
                        Inspect per specification <specs>FI-625</specs>.
                    </step></Location></root>','059A2000-7549-4B49-8E0C-2DE6B2771EF4','May 16 2005  4:34PM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (68,'LL Road Pedal',NULL,NULL,'218B016C-7454-4193-B518-21955C783D72','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (69,'ML Road Pedal',NULL,NULL,'3CDF61D6-6209-436F-B235-82E8F159208B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (70,'HL Road Pedal',NULL,NULL,'35677B42-72CA-4D9E-A966-DD874B83EF45','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (71,'LL Mountain Seat/Saddle 1',NULL,NULL,'A166AF4C-87BB-41AA-8496-D76B26008FB3','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (72,'ML Mountain Seat/Saddle 1',NULL,NULL,'BAA9405B-68CA-4C18-BC9C-1C4ACF49BAFC','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (73,'HL Mountain Seat/Saddle 1',NULL,NULL,'BBE4918F-198D-43C7-9F4B-79BC2AA08F2B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (74,'LL Road Seat/Saddle 2',NULL,NULL,'24E3E7D4-4053-4035-9D69-F451642F0C1E','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (75,'ML Road Seat/Saddle 1',NULL,NULL,'394ED69C-2CC4-4A85-9080-8534112B66FE','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (76,'HL Road Seat/Saddle 1',NULL,NULL,'B83AB7AE-BA3F-40DF-8296-361915A3A60C','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (77,'ML Road Rear Wheel',NULL,NULL,'15702F98-BD92-4FE8-86BC-52F5FD049D3D','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (78,'HL Road Rear Wheel',NULL,NULL,'438CBCFA-05FF-4A29-AD95-ECF41DCB83D5','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (79,'LL Mountain Seat/Saddle 2',NULL,NULL,'8BBEB399-5A87-4E40-9F52-462FB54F2183','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (80,'ML Mountain Seat/Saddle 2',NULL,NULL,'5CEFBB6E-3B7E-414F-AC1B-8F6DF741FB21','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (81,'HL Mountain Seat/Saddle 2',NULL,NULL,'98726F80-E9B9-4141-9CF5-BD2EF07DCE25','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (82,'LL Road Seat/Saddle 1',NULL,NULL,'00CE9171-8944-4D49-BA37-485C1D122F5C','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (83,'ML Road Seat/Saddle 2',NULL,NULL,'FEEB8440-446E-4DF8-9482-D529C4FC5E8F','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (84,'HL Road Seat/Saddle 2',NULL,NULL,'0D3A6AD7-6891-4DE9-B14F-E1A841EB220C','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (85,'LL Mountain Tire',NULL,NULL,'E3CDC5DD-27C3-4891-9D5E-0D46D1B8457F','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (86,'ML Mountain Tire',NULL,NULL,'0434F63A-A361-4D0B-A9FC-8AC2A866CE85','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (87,'HL Mountain Tire',NULL,NULL,'CE1B1064-6679-4212-8F56-2B2617EC56A5','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (88,'LL Road Tire',NULL,NULL,'E7B00DFF-8136-4947-B503-994584CC89E7','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (89,'ML Road Tire',NULL,NULL,'D566EB0F-6945-43D8-BC40-BB3D2F4EF7ED','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (90,'HL Road Tire',NULL,NULL,'A4B205DF-955A-494E-8428-1898AEA76F24','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (91,'Touring Tire',NULL,NULL,'3BCC63D6-9340-4B93-B5F2-73FA90758BF5','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (92,'Mountain Tire Tube',NULL,NULL,'8CFBE7F2-EEC3-4BA6-8187-C8A3614F1F0B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (93,'Road Tire Tube',NULL,NULL,'2771D2D2-2E35-4C12-966E-CE9070DF6D53','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (94,'Touring Tire Tube',NULL,NULL,'DEEEA9BC-3C8C-4E73-B6B0-64C81A5D99E3','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (95,'LL Bottom Bracket',NULL,NULL,'217E7475-D3F4-46FA-836A-D9E53103E71B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (96,'ML Bottom Bracket',NULL,NULL,'09CAA74E-F47B-4FCA-B206-9D3E46DF9751','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (97,'HL Bottom Bracket',NULL,NULL,'816360E1-3DEE-4568-BF2F-9828243D887B','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (98,'Chain',NULL,NULL,'ACA920B2-D0F9-49F3-B879-573202B08C2F','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (99,'LL Crankset',NULL,NULL,'5B59F032-9B73-4D90-B252-EAFD6A871FF1','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (100,'ML Crankset',NULL,NULL,'68C6CB29-D94A-40C5-AAAD-90AA6E7C5EA1','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (101,'HL Crankset',NULL,NULL,'809668A3-D492-41FB-A196-CFE092A12AA2','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (102,'Front Brakes',NULL,NULL,'1099A23A-C9ED-41B1-8CC1-E2C1C54A10C8','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (103,'Front Derailleur',NULL,NULL,'10E0C8FD-CA13-437B-8E22-51853AE160A7','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (104,'LL Fork',NULL,NULL,'0481D7E1-4970-4EFA-A560-020F6579918D','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (105,'ML Fork',NULL,NULL,'5F115AA4-0553-4478-84B3-5DCF3ABE0D08','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (106,'HL Fork',NULL,NULL,'7706A8FD-9513-40BC-95E8-301B55B67DB2','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (107,'Hydration Pack',NULL,NULL,'CFEEF30F-F059-4447-92A8-47001E69F3DB','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (108,'Taillight',NULL,NULL,'DBA643D4-4CF2-4507-B947-E817D8C5792B','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (109,'Headlights - Dual-Beam',NULL,NULL,'7B17EBF1-CB73-4934-9689-1DC26CF22D9C','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (110,'Headlights - Weatherproof',NULL,NULL,'1FADB88F-AF88-4E94-BB1E-6158C48E6B40','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (111,'Water Bottle',NULL,NULL,'3688268A-260C-48BF-BF71-FFF350D4D3D5','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (112,'Mountain Bottle Cage',NULL,NULL,'2194E65B-9C13-46E1-A655-3EBFF8A96719','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (113,'Road Bottle Cage',NULL,NULL,'9416C2DD-55D8-469D-8EDF-EF447C511897','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (114,'Patch kit',NULL,NULL,'7C738101-C01E-45A2-A0E0-B28AEBA1DC40','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (115,'Cable Lock',NULL,NULL,'E7E17F11-A7FD-4C3C-B701-68F0AE26143E','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (116,'Minipump',NULL,NULL,'90CEF1A7-D817-403E-814C-40E305EEEFEF','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (117,'Mountain Pump',NULL,NULL,'B35598F6-B413-4138-8081-5DC7D4C64B64','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (118,'Hitch Rack - 4-Bike',NULL,NULL,'F570E0D1-E978-4FF2-B5B1-08F01AB60219','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (119,'Bike Wash',NULL,NULL,'90B1B93D-EBC8-44A2-AC08-CDD1D20CA39C','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (120,'Touring-Panniers',NULL,NULL,'F06999A1-3AA7-4E85-B8CB-049EB2C391FA','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (121,'Fender Set - Mountain',NULL,NULL,'C88D1136-A8BB-46BB-94AA-8C1854F813CC','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (122,'All-Purpose Bike Stand',NULL,NULL,'6EAB8607-D927-40E1-AF30-D8A2A953050C','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (123,'LL Mountain Rear Wheel',NULL,NULL,'29521F66-2926-471F-867B-668B0B9EC2B0','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (124,'ML Mountain Rear Wheel',NULL,NULL,'D968D774-778E-4399-A3C5-375176418229','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (125,'HL Mountain Rear Wheel',NULL,NULL,'95450545-ADF7-48F3-899E-964DE8920DC6','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (126,'LL Road Rear Wheel',NULL,NULL,'95946BD4-C6D9-4344-8066-317D8957EA21','Jun  1 2002 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (127,'Rear Derailleur',NULL,NULL,'F9327E5D-F8B6-40C5-BFA9-63F886BDFC24','Jun  1 2003 12:00AM')
Insert Into [ProductModel] ([ProductModelID],[Name],[CatalogDescription],[Instructions],[rowguid],[ModifiedDate]) Values (128,'Rear Brakes',NULL,NULL,'71D47AFD-DA3A-43F1-83AD-69C71F96EF33','Jun  1 2003 12:00AM')

SELECT COUNT(*) AS [Product Record Count] FROM Product
SELECT COUNT(*) AS [Product Model Record Count] FROM ProductModel